// This file was generated. DO NOT EDIT.
use crate::icons;
use pyo3::prelude::*;

pub(super) fn bind_part_0(m: &Bound<PyModule>) -> PyResult<()> {
    m.add("FILE_ZIP_16", icons::FILE_ZIP_16)?;
    m.add("PERSON_16", icons::PERSON_16)?;
    m.add("AGENT_16", icons::AGENT_16)?;
    m.add("REPO_FORKED_24", icons::REPO_FORKED_24)?;
    m.add("FISCAL_HOST_24", icons::FISCAL_HOST_24)?;
    m.add("TOOLS_16", icons::TOOLS_16)?;
    m.add("GIT_PULL_REQUEST_24", icons::GIT_PULL_REQUEST_24)?;
    m.add("BOOKMARK_16", icons::BOOKMARK_16)?;
    m.add("THUMBSDOWN_16", icons::THUMBSDOWN_16)?;
    m.add("COPILOT_24", icons::COPILOT_24)?;
    m.add("PLUS_24", icons::PLUS_24)?;
    m.add("UNLOCK_16", icons::UNLOCK_16)?;
    m.add("FILE_SYMLINK_FILE_24", icons::FILE_SYMLINK_FILE_24)?;
    m.add("TOOLS_24", icons::TOOLS_24)?;
    m.add("LOOP_24", icons::LOOP_24)?;
    m.add("CACHE_24", icons::CACHE_24)?;
    m.add("CODESCAN_24", icons::CODESCAN_24)?;
    m.add("INFINITY_16", icons::INFINITY_16)?;
    m.add("FEED_ISSUE_DRAFT_16", icons::FEED_ISSUE_DRAFT_16)?;
    m.add("TRIANGLE_RIGHT_24", icons::TRIANGLE_RIGHT_24)?;
    m.add("UNDO_24", icons::UNDO_24)?;
    m.add("DOWNLOAD_16", icons::DOWNLOAD_16)?;
    m.add("KEY_ASTERISK_16", icons::KEY_ASTERISK_16)?;
    m.add("TABLE_16", icons::TABLE_16)?;
    m.add("FEED_TROPHY_16", icons::FEED_TROPHY_16)?;
    m.add("FOLD_24", icons::FOLD_24)?;
    m.add("MOON_24", icons::MOON_24)?;
    m.add("LAW_24", icons::LAW_24)?;
    m.add("FILE_MEDIA_16", icons::FILE_MEDIA_16)?;
    m.add("MAXIMIZE_16", icons::MAXIMIZE_16)?;
    m.add("COMMAND_PALETTE_24", icons::COMMAND_PALETTE_24)?;
    m.add("MILESTONE_24", icons::MILESTONE_24)?;
    m.add("SPARKLE_16", icons::SPARKLE_16)?;
    m.add("X_CIRCLE_24", icons::X_CIRCLE_24)?;
    m.add("SMILEY_NEUTRAL_16", icons::SMILEY_NEUTRAL_16)?;
    m.add("UNLOCK_24", icons::UNLOCK_24)?;
    m.add("METER_24", icons::METER_24)?;
    m.add("HOME_16", icons::HOME_16)?;
    m.add("FILTER_REMOVE_16", icons::FILTER_REMOVE_16)?;
    m.add("UPLOAD_16", icons::UPLOAD_16)?;
    m.add("MOVE_TO_TOP_16", icons::MOVE_TO_TOP_16)?;
    m.add("STOPWATCH_24", icons::STOPWATCH_24)?;
    m.add("DIFF_MODIFIED_24", icons::DIFF_MODIFIED_24)?;
    m.add("DASH_16", icons::DASH_16)?;
    m.add("FILE_BADGE_16", icons::FILE_BADGE_16)?;
    m.add("PLUG_24", icons::PLUG_24)?;
    m.add("PROJECT_TEMPLATE_16", icons::PROJECT_TEMPLATE_16)?;
    m.add("UNVERIFIED_16", icons::UNVERIFIED_16)?;
    m.add("PACKAGE_DEPENDENCIES_24", icons::PACKAGE_DEPENDENCIES_24)?;
    m.add("CIRCLE_SLASH_16", icons::CIRCLE_SLASH_16)?;
    m.add("DEVICE_MOBILE_16", icons::DEVICE_MOBILE_16)?;
    m.add("LOOP_16", icons::LOOP_16)?;
    m.add("BEAKER_16", icons::BEAKER_16)?;
    m.add("STAR_FILL_16", icons::STAR_FILL_16)?;
    m.add("PERSON_24", icons::PERSON_24)?;
    m.add("CHECK_24", icons::CHECK_24)?;
    m.add("REDO_24", icons::REDO_24)?;
    m.add("PROJECT_TEMPLATE_24", icons::PROJECT_TEMPLATE_24)?;
    m.add("ORGANIZATION_24", icons::ORGANIZATION_24)?;
    m.add("BROADCAST_16", icons::BROADCAST_16)?;
    m.add("MOVE_TO_BOTTOM_16", icons::MOVE_TO_BOTTOM_16)?;
    m.add("TROPHY_24", icons::TROPHY_24)?;
    m.add("MILESTONE_16", icons::MILESTONE_16)?;
    m.add("INFO_16", icons::INFO_16)?;
    m.add("COMPOSE_16", icons::COMPOSE_16)?;
    m.add("SYNC_24", icons::SYNC_24)?;
    m.add("DEVICES_16", icons::DEVICES_16)?;
    m.add("MCP_24", icons::MCP_24)?;
    m.add("SQUIRREL_16", icons::SQUIRREL_16)?;
    m.add("ITALIC_16", icons::ITALIC_16)?;
    m.add("SYNC_16", icons::SYNC_16)?;
    m.add("DEVICE_MOBILE_24", icons::DEVICE_MOBILE_24)?;
    m.add("ARROW_UP_LEFT_16", icons::ARROW_UP_LEFT_16)?;
    m.add("REPO_CLONE_16", icons::REPO_CLONE_16)?;
    m.add("READ_24", icons::READ_24)?;
    m.add("CHECKBOX_16", icons::CHECKBOX_16)?;
    m.add("COPY_24", icons::COPY_24)?;
    m.add("ARROW_LEFT_24", icons::ARROW_LEFT_24)?;
    m.add("SIDEBAR_EXPAND_24", icons::SIDEBAR_EXPAND_24)?;
    m.add("CHEVRON_LEFT_16", icons::CHEVRON_LEFT_16)?;
    m.add("MOVE_TO_END_16", icons::MOVE_TO_END_16)?;
    m.add("MORTAR_BOARD_24", icons::MORTAR_BOARD_24)?;
    m.add(
        "FEED_PULL_REQUEST_CLOSED_16",
        icons::FEED_PULL_REQUEST_CLOSED_16,
    )?;
    m.add("GRABBER_16", icons::GRABBER_16)?;
    m.add("PAPERCLIP_16", icons::PAPERCLIP_16)?;
    m.add("GIT_MERGE_16", icons::GIT_MERGE_16)?;
    m.add("DIFF_ADDED_24", icons::DIFF_ADDED_24)?;
    m.add("NORTH_STAR_16", icons::NORTH_STAR_16)?;
    m.add("CALENDAR_24", icons::CALENDAR_24)?;
    m.add("TAB_16", icons::TAB_16)?;
    m.add("MARK_GITHUB_16", icons::MARK_GITHUB_16)?;
    m.add("SCREEN_NORMAL_16", icons::SCREEN_NORMAL_16)?;
    m.add("BOLD_16", icons::BOLD_16)?;
    m.add("FILE_24", icons::FILE_24)?;
    m.add("PENCIL_24", icons::PENCIL_24)?;
    m.add("CONTAINER_16", icons::CONTAINER_16)?;
    m.add("LINK_24", icons::LINK_24)?;
    m.add("TERMINAL_24", icons::TERMINAL_24)?;
    m.add("SPLIT_VIEW_24", icons::SPLIT_VIEW_24)?;
    m.add("BOOKMARK_SLASH_FILL_16", icons::BOOKMARK_SLASH_FILL_16)?;
    m.add("BOOK_16", icons::BOOK_16)?;
    m.add("BELL_FILL_24", icons::BELL_FILL_24)?;
    m.add("PULSE_24", icons::PULSE_24)?;
    m.add("REPO_PULL_16", icons::REPO_PULL_16)?;
    m.add("FOLD_DOWN_24", icons::FOLD_DOWN_24)?;
    m.add("CHEVRON_RIGHT_24", icons::CHEVRON_RIGHT_24)?;
    m.add("MINIMIZE_16", icons::MINIMIZE_16)?;
    m.add("FILE_SUBMODULE_16", icons::FILE_SUBMODULE_16)?;
    m.add("GIT_BRANCH_16", icons::GIT_BRANCH_16)?;
    m.add("FILE_BINARY_16", icons::FILE_BINARY_16)?;
    m.add("REPO_16", icons::REPO_16)?;
    m.add("PAPER_AIRPLANE_24", icons::PAPER_AIRPLANE_24)?;
    m.add("SHARE_ANDROID_16", icons::SHARE_ANDROID_16)?;
    m.add("FLAME_24", icons::FLAME_24)?;
    m.add("HOME_FILL_16", icons::HOME_FILL_16)?;
    m.add("CHEVRON_LEFT_24", icons::CHEVRON_LEFT_24)?;
    m.add("SHIELD_CHECK_24", icons::SHIELD_CHECK_24)?;
    m.add("VSCODE_16", icons::VSCODE_16)?;
    m.add("SEARCH_24", icons::SEARCH_24)?;
    m.add("CLOCK_16", icons::CLOCK_16)?;
    m.add("CLOCK_FILL_24", icons::CLOCK_FILL_24)?;
    m.add("ARROW_LEFT_16", icons::ARROW_LEFT_16)?;
    m.add("FEED_STAR_16", icons::FEED_STAR_16)?;
    m.add("COMMAND_PALETTE_16", icons::COMMAND_PALETTE_16)?;
    m.add("ARROW_BOTH_16", icons::ARROW_BOTH_16)?;
    m.add("GIT_MERGE_24", icons::GIT_MERGE_24)?;
    m.add("STAR_FILL_24", icons::STAR_FILL_24)?;
    m.add("BELL_24", icons::BELL_24)?;
    m.add("RUBY_24", icons::RUBY_24)?;
    m.add("PACKAGE_24", icons::PACKAGE_24)?;
    m.add("SKIP_FILL_24", icons::SKIP_FILL_24)?;
    m.add("GRAPH_BAR_HORIZONTAL_24", icons::GRAPH_BAR_HORIZONTAL_24)?;
    m.add("SKIP_FILL_16", icons::SKIP_FILL_16)?;
    m.add("CROSS_REFERENCE_24", icons::CROSS_REFERENCE_24)?;
    m.add("HEADING_24", icons::HEADING_24)?;
    m.add("UNLINK_24", icons::UNLINK_24)?;
    m.add("ROWS_16", icons::ROWS_16)?;
    m.add("QUOTE_16", icons::QUOTE_16)?;
    m.add("NO_ENTRY_24", icons::NO_ENTRY_24)?;
    m.add("QUOTE_24", icons::QUOTE_24)?;
    m.add("AI_MODEL_16", icons::AI_MODEL_16)?;
    m.add("PROJECT_SYMLINK_16", icons::PROJECT_SYMLINK_16)?;
    m.add("MOVE_TO_BOTTOM_24", icons::MOVE_TO_BOTTOM_24)?;
    m.add("INBOX_16", icons::INBOX_16)?;
    m.add("SMILEY_FROWN_24", icons::SMILEY_FROWN_24)?;
    m.add("FILE_ZIP_24", icons::FILE_ZIP_24)?;
    m.add("ACCESSIBILITY_INSET_24", icons::ACCESSIBILITY_INSET_24)?;
    m.add("ISSUE_OPENED_24", icons::ISSUE_OPENED_24)?;
    m.add("STACK_24", icons::STACK_24)?;
    m.add("FOLD_DOWN_16", icons::FOLD_DOWN_16)?;
    m.add("QUESTION_24", icons::QUESTION_24)?;
    m.add("CHEVRON_UP_24", icons::CHEVRON_UP_24)?;
    m.add("BLOCKED_24", icons::BLOCKED_24)?;
    m.add("MOON_16", icons::MOON_16)?;
    m.add("ZOOM_IN_24", icons::ZOOM_IN_24)?;
    m.add("ROCKET_24", icons::ROCKET_24)?;
    m.add("TRIANGLE_DOWN_16", icons::TRIANGLE_DOWN_16)?;
    m.add("ARROW_DOWN_16", icons::ARROW_DOWN_16)?;
    m.add("CHECKLIST_16", icons::CHECKLIST_16)?;
    m.add("REL_FILE_PATH_24", icons::REL_FILE_PATH_24)?;
    m.add("EYE_16", icons::EYE_16)?;
    m.add("UNWRAP_24", icons::UNWRAP_24)?;
    m.add("TERMINAL_16", icons::TERMINAL_16)?;
    m.add("X_CIRCLE_FILL_24", icons::X_CIRCLE_FILL_24)?;
    m.add("GIT_COMMIT_24", icons::GIT_COMMIT_24)?;
    m.add("FOLD_UP_16", icons::FOLD_UP_16)?;
    m.add("FEED_PLUS_16", icons::FEED_PLUS_16)?;
    m.add("GEAR_24", icons::GEAR_24)?;
    m.add("VSCODE_48", icons::VSCODE_48)?;
    m.add("TASKLIST_24", icons::TASKLIST_24)?;
    m.add("DOT_FILL_16", icons::DOT_FILL_16)?;
    m.add("DESKTOP_DOWNLOAD_16", icons::DESKTOP_DOWNLOAD_16)?;
    m.add("LOCATION_24", icons::LOCATION_24)?;
    m.add("INBOX_FILL_24", icons::INBOX_FILL_24)?;
    m.add("PASSKEY_FILL_24", icons::PASSKEY_FILL_24)?;
    m.add("NODE_16", icons::NODE_16)?;
    m.add("GIT_BRANCH_CHECK_16", icons::GIT_BRANCH_CHECK_16)?;
    m.add("FISCAL_HOST_16", icons::FISCAL_HOST_16)?;
    m.add("SHIELD_CHECK_16", icons::SHIELD_CHECK_16)?;
    m.add(
        "FILE_DIRECTORY_OPEN_FILL_16",
        icons::FILE_DIRECTORY_OPEN_FILL_16,
    )?;
    m.add("MENTION_24", icons::MENTION_24)?;
    m.add("DEVICE_DESKTOP_16", icons::DEVICE_DESKTOP_16)?;
    m.add("ALERT_FILL_24", icons::ALERT_FILL_24)?;
    m.add("PAUSE_16", icons::PAUSE_16)?;
    m.add("MUTE_16", icons::MUTE_16)?;
    m.add("TRIANGLE_UP_24", icons::TRIANGLE_UP_24)?;
    m.add("PROJECT_ROADMAP_24", icons::PROJECT_ROADMAP_24)?;
    m.add("STOPWATCH_16", icons::STOPWATCH_16)?;
    m.add("ORGANIZATION_16", icons::ORGANIZATION_16)?;
    m.add("ARROW_DOWN_RIGHT_24", icons::ARROW_DOWN_RIGHT_24)?;
    m.add("ALERT_16", icons::ALERT_16)?;
    m.add("WORKFLOW_16", icons::WORKFLOW_16)?;
    m.add("REL_FILE_PATH_16", icons::REL_FILE_PATH_16)?;
    m.add("DIFF_RENAMED_16", icons::DIFF_RENAMED_16)?;
    m.add("GIT_MERGE_QUEUE_24", icons::GIT_MERGE_QUEUE_24)?;
    m.add("VERIFIED_16", icons::VERIFIED_16)?;
    m.add("QUESTION_16", icons::QUESTION_16)?;
    m.add("COPY_16", icons::COPY_16)?;
    m.add("PAPER_AIRPLANE_16", icons::PAPER_AIRPLANE_16)?;
    m.add("SHIELD_SLASH_16", icons::SHIELD_SLASH_16)?;
    Ok(())
}
