// This file was generated. DO NOT EDIT.
use crate::icons;
use pyo3::prelude::*;

pub(super) fn bind_part_2(m: &Bound<PyModule>) -> PyResult<()> {
    m.add("WRAP_24", icons::WRAP_24)?;
    m.add("SIGN_OUT_16", icons::SIGN_OUT_16)?;
    m.add("DIFF_RENAMED_24", icons::DIFF_RENAMED_24)?;
    m.add("LIST_ORDERED_16", icons::LIST_ORDERED_16)?;
    m.add("REPORT_16", icons::REPORT_16)?;
    m.add("TRASH_24", icons::TRASH_24)?;
    m.add("SMILEY_GRIN_16", icons::SMILEY_GRIN_16)?;
    m.add("STRIKETHROUGH_16", icons::STRIKETHROUGH_16)?;
    m.add("DISCUSSION_DUPLICATE_16", icons::DISCUSSION_DUPLICATE_16)?;
    m.add("FILE_SYMLINK_FILE_16", icons::FILE_SYMLINK_FILE_16)?;
    m.add("UNFOLD_24", icons::UNFOLD_24)?;
    m.add("PACKAGE_DEPENDENTS_24", icons::PACKAGE_DEPENDENTS_24)?;
    m.add("TRIANGLE_DOWN_24", icons::TRIANGLE_DOWN_24)?;
    m.add("SHIELD_SLASH_24", icons::SHIELD_SLASH_24)?;
    m.add("BOOLEAN_ON_16", icons::BOOLEAN_ON_16)?;
    m.add("ITERATIONS_16", icons::ITERATIONS_16)?;
    m.add("DUPLICATE_16", icons::DUPLICATE_16)?;
    m.add("DEVICE_CAMERA_16", icons::DEVICE_CAMERA_16)?;
    m.add("CREDIT_CARD_24", icons::CREDIT_CARD_24)?;
    m.add("PLUS_CIRCLE_24", icons::PLUS_CIRCLE_24)?;
    m.add("GIT_COMMIT_16", icons::GIT_COMMIT_16)?;
    m.add("SHIELD_X_24", icons::SHIELD_X_24)?;
    m.add("SINGLE_SELECT_24", icons::SINGLE_SELECT_24)?;
    m.add("ZAP_24", icons::ZAP_24)?;
    m.add("PAUSE_24", icons::PAUSE_24)?;
    m.add("SHARE_ANDROID_24", icons::SHARE_ANDROID_24)?;
    m.add("REPO_PULL_24", icons::REPO_PULL_24)?;
    m.add("LIGHT_BULB_24", icons::LIGHT_BULB_24)?;
    m.add("BRIEFCASE_24", icons::BRIEFCASE_24)?;
    m.add(
        "FILE_DIRECTORY_OPEN_FILL_24",
        icons::FILE_DIRECTORY_OPEN_FILL_24,
    )?;
    m.add("TELESCOPE_16", icons::TELESCOPE_16)?;
    m.add("CLOUD_OFFLINE_16", icons::CLOUD_OFFLINE_16)?;
    m.add("FOCUS_CENTER_24", icons::FOCUS_CENTER_24)?;
    m.add("SIDEBAR_EXPAND_16", icons::SIDEBAR_EXPAND_16)?;
    m.add("MARKDOWN_16", icons::MARKDOWN_16)?;
    m.add("CODE_SQUARE_16", icons::CODE_SQUARE_16)?;
    m.add("LOGO_GITHUB_24", icons::LOGO_GITHUB_24)?;
    m.add("DIFF_24", icons::DIFF_24)?;
    m.add("MAIL_24", icons::MAIL_24)?;
    m.add("CHEVRON_RIGHT_16", icons::CHEVRON_RIGHT_16)?;
    m.add("SUN_16", icons::SUN_16)?;
    m.add("CLOUD_16", icons::CLOUD_16)?;
    m.add("MOVE_TO_START_24", icons::MOVE_TO_START_24)?;
    m.add("ISSUE_TRACKED_BY_24", icons::ISSUE_TRACKED_BY_24)?;
    m.add("FEED_FORKED_16", icons::FEED_FORKED_16)?;
    m.add("EYE_CLOSED_24", icons::EYE_CLOSED_24)?;
    m.add("HASH_24", icons::HASH_24)?;
    m.add("COMMENT_16", icons::COMMENT_16)?;
    m.add("SMILEY_24", icons::SMILEY_24)?;
    m.add("GOAL_24", icons::GOAL_24)?;
    m.add("ISSUE_REOPENED_24", icons::ISSUE_REOPENED_24)?;
    m.add("REPO_PUSH_16", icons::REPO_PUSH_16)?;
    m.add("PLAY_24", icons::PLAY_24)?;
    m.add("DOWNLOAD_24", icons::DOWNLOAD_24)?;
    m.add("ITERATIONS_24", icons::ITERATIONS_24)?;
    m.add("THREE_BARS_16", icons::THREE_BARS_16)?;
    m.add("ISSUE_DRAFT_16", icons::ISSUE_DRAFT_16)?;
    m.add("SPACING_MEDIUM_24", icons::SPACING_MEDIUM_24)?;
    m.add(
        "TRACKED_BY_CLOSED_NOT_PLANNED_24",
        icons::TRACKED_BY_CLOSED_NOT_PLANNED_24,
    )?;
    m.add("SIDEBAR_COLLAPSE_16", icons::SIDEBAR_COLLAPSE_16)?;
    m.add("NO_ENTRY_FILL_12", icons::NO_ENTRY_FILL_12)?;
    m.add("SLIDERS_24", icons::SLIDERS_24)?;
    m.add("ISSUE_CLOSED_24", icons::ISSUE_CLOSED_24)?;
    m.add("PERSON_FILL_24", icons::PERSON_FILL_24)?;
    m.add("GRAPH_16", icons::GRAPH_16)?;
    m.add("REPO_TEMPLATE_16", icons::REPO_TEMPLATE_16)?;
    m.add("ZOOM_IN_16", icons::ZOOM_IN_16)?;
    m.add("BELL_SLASH_16", icons::BELL_SLASH_16)?;
    m.add("UNLINK_16", icons::UNLINK_16)?;
    m.add("CLOUD_OFFLINE_24", icons::CLOUD_OFFLINE_24)?;
    m.add("ARROW_DOWN_LEFT_16", icons::ARROW_DOWN_LEFT_16)?;
    m.add("STAR_24", icons::STAR_24)?;
    m.add("TASKLIST_16", icons::TASKLIST_16)?;
    m.add("CODESPACES_16", icons::CODESPACES_16)?;
    m.add("TAB_EXTERNAL_24", icons::TAB_EXTERNAL_24)?;
    m.add("REPORT_24", icons::REPORT_24)?;
    m.add("FEED_ISSUE_OPEN_16", icons::FEED_ISSUE_OPEN_16)?;
    m.add("BLOCKED_16", icons::BLOCKED_16)?;
    m.add("PACKAGE_DEPENDENCIES_16", icons::PACKAGE_DEPENDENCIES_16)?;
    m.add("ARROW_RIGHT_24", icons::ARROW_RIGHT_24)?;
    m.add("PLUS_CIRCLE_16", icons::PLUS_CIRCLE_16)?;
    m.add("FILE_DIRECTORY_FILL_16", icons::FILE_DIRECTORY_FILL_16)?;
    m.add("SMILEY_FRUSTRATED_16", icons::SMILEY_FRUSTRATED_16)?;
    m.add("SERVER_24", icons::SERVER_24)?;
    m.add("CLOUD_24", icons::CLOUD_24)?;
    m.add("TAG_16", icons::TAG_16)?;
    m.add("THUMBSUP_16", icons::THUMBSUP_16)?;
    m.add("MULTI_SELECT_16", icons::MULTI_SELECT_16)?;
    m.add("TELESCOPE_FILL_16", icons::TELESCOPE_FILL_16)?;
    m.add("SIGN_OUT_24", icons::SIGN_OUT_24)?;
    m.add("TELESCOPE_24", icons::TELESCOPE_24)?;
    m.add("PENCIL_AI_24", icons::PENCIL_AI_24)?;
    m.add("PACKAGE_DEPENDENTS_16", icons::PACKAGE_DEPENDENTS_16)?;
    m.add("NODE_24", icons::NODE_24)?;
    m.add("TYPOGRAPHY_16", icons::TYPOGRAPHY_16)?;
    m.add("SQUARE_FILL_16", icons::SQUARE_FILL_16)?;
    m.add("COPILOT_16", icons::COPILOT_16)?;
    m.add("GRAPH_BAR_VERTICAL_24", icons::GRAPH_BAR_VERTICAL_24)?;
    m.add("REPO_FORKED_16", icons::REPO_FORKED_16)?;
    m.add("MOVE_TO_TOP_24", icons::MOVE_TO_TOP_24)?;
    m.add("DIFF_IGNORED_16", icons::DIFF_IGNORED_16)?;
    m.add("DIFF_IGNORED_24", icons::DIFF_IGNORED_24)?;
    m.add("X_16", icons::X_16)?;
    m.add("ID_BADGE_16", icons::ID_BADGE_16)?;
    m.add("PLUG_16", icons::PLUG_16)?;
    m.add("X_CIRCLE_FILL_12", icons::X_CIRCLE_FILL_12)?;
    m.add("VERSIONS_16", icons::VERSIONS_16)?;
    m.add("TRIANGLE_LEFT_24", icons::TRIANGLE_LEFT_24)?;
    m.add("SCREEN_FULL_24", icons::SCREEN_FULL_24)?;
    m.add("COMMENT_DISCUSSION_24", icons::COMMENT_DISCUSSION_24)?;
    m.add("CHECKLIST_24", icons::CHECKLIST_24)?;
    m.add("SKIP_16", icons::SKIP_16)?;
    m.add("DIAMOND_24", icons::DIAMOND_24)?;
    m.add("CHECKBOX_FILL_24", icons::CHECKBOX_FILL_24)?;
    m.add("FILTER_16", icons::FILTER_16)?;
    m.add("PROJECT_16", icons::PROJECT_16)?;
    m.add("BOOKMARK_FILLED_16", icons::BOOKMARK_FILLED_16)?;
    m.add("FOLD_UP_24", icons::FOLD_UP_24)?;
    m.add("NO_ENTRY_16", icons::NO_ENTRY_16)?;
    m.add("REPO_TEMPLATE_24", icons::REPO_TEMPLATE_24)?;
    m.add("HISTORY_24", icons::HISTORY_24)?;
    m.add("ACCESSIBILITY_24", icons::ACCESSIBILITY_24)?;
    m.add("ARROW_UP_RIGHT_16", icons::ARROW_UP_RIGHT_16)?;
    m.add("CALENDAR_16", icons::CALENDAR_16)?;
    m.add("FOCUS_CENTER_16", icons::FOCUS_CENTER_16)?;
    m.add("CHECK_CIRCLE_FILL_16", icons::CHECK_CIRCLE_FILL_16)?;
    m.add("LOCK_24", icons::LOCK_24)?;
    m.add("HUBOT_16", icons::HUBOT_16)?;
    m.add("VIDEO_16", icons::VIDEO_16)?;
    m.add("STRIKETHROUGH_24", icons::STRIKETHROUGH_24)?;
    m.add(
        "FEED_PULL_REQUEST_OPEN_16",
        icons::FEED_PULL_REQUEST_OPEN_16,
    )?;
    m.add("THREE_BARS_24", icons::THREE_BARS_24)?;
    m.add("SPACE_16", icons::SPACE_16)?;
    m.add("CHEVRON_DOWN_16", icons::CHEVRON_DOWN_16)?;
    m.add("DATABASE_24", icons::DATABASE_24)?;
    m.add("ARROW_UP_RIGHT_24", icons::ARROW_UP_RIGHT_24)?;
    m.add("KEY_ASTERISK_24", icons::KEY_ASTERISK_24)?;
    m.add(
        "GIT_PULL_REQUEST_CLOSED_16",
        icons::GIT_PULL_REQUEST_CLOSED_16,
    )?;
    m.add("GRAPH_24", icons::GRAPH_24)?;
    m.add("CODE_OF_CONDUCT_24", icons::CODE_OF_CONDUCT_24)?;
    m.add("CPU_24", icons::CPU_24)?;
    m.add("BOLD_24", icons::BOLD_24)?;
    m.add("PROJECT_ROADMAP_16", icons::PROJECT_ROADMAP_16)?;
    m.add("SPARKLE_FILL_16", icons::SPARKLE_FILL_16)?;
    m.add("PENCIL_16", icons::PENCIL_16)?;
    m.add("PIN_24", icons::PIN_24)?;
    m.add("EYE_CLOSED_16", icons::EYE_CLOSED_16)?;
    m.add("CHECK_CIRCLE_16", icons::CHECK_CIRCLE_16)?;
    m.add("LINK_EXTERNAL_24", icons::LINK_EXTERNAL_24)?;
    m.add("TYPOGRAPHY_24", icons::TYPOGRAPHY_24)?;
    m.add("WRAP_16", icons::WRAP_16)?;
    m.add("HOURGLASS_24", icons::HOURGLASS_24)?;
    m.add("DEVICE_CAMERA_VIDEO_16", icons::DEVICE_CAMERA_VIDEO_16)?;
    m.add("GIT_MERGE_QUEUE_16", icons::GIT_MERGE_QUEUE_16)?;
    m.add("TRASH_16", icons::TRASH_16)?;
    m.add("DIFF_16", icons::DIFF_16)?;
    m.add("DEPENDABOT_16", icons::DEPENDABOT_16)?;
    m.add("CODESPACES_24", icons::CODESPACES_24)?;
    m.add("BROWSER_24", icons::BROWSER_24)?;
    m.add("PIN_16", icons::PIN_16)?;
    m.add("SQUARE_16", icons::SQUARE_16)?;
    m.add("DISCUSSION_OUTDATED_24", icons::DISCUSSION_OUTDATED_24)?;
    m.add("SHIELD_24", icons::SHIELD_24)?;
    m.add("UNMUTE_24", icons::UNMUTE_24)?;
    m.add("STOP_24", icons::STOP_24)?;
    m.add("SMILEY_FRUSTRATED_24", icons::SMILEY_FRUSTRATED_24)?;
    m.add("UNREAD_16", icons::UNREAD_16)?;
    m.add(
        "GIT_PULL_REQUEST_DRAFT_16",
        icons::GIT_PULL_REQUEST_DRAFT_16,
    )?;
    m.add("PAINTBRUSH_24", icons::PAINTBRUSH_24)?;
    m.add("GIT_BRANCH_24", icons::GIT_BRANCH_24)?;
    m.add("COMMENT_AI_16", icons::COMMENT_AI_16)?;
    m.add("INBOX_24", icons::INBOX_24)?;
    m.add("GRAPH_BAR_HORIZONTAL_16", icons::GRAPH_BAR_HORIZONTAL_16)?;
    m.add("FILE_SUBMODULE_24", icons::FILE_SUBMODULE_24)?;
    m.add("DATABASE_16", icons::DATABASE_16)?;
    m.add("CODE_REVIEW_24", icons::CODE_REVIEW_24)?;
    m.add("SHIELD_X_16", icons::SHIELD_X_16)?;
    m.add("FEED_ISSUE_REOPEN_16", icons::FEED_ISSUE_REOPEN_16)?;
    m.add("CROSSHAIRS_16", icons::CROSSHAIRS_16)?;
    m.add("COPILOT_ERROR_16", icons::COPILOT_ERROR_16)?;
    m.add("ITALIC_24", icons::ITALIC_24)?;
    m.add("LINK_16", icons::LINK_16)?;
    m.add("SPACING_LARGE_24", icons::SPACING_LARGE_24)?;
    m.add("KEBAB_HORIZONTAL_16", icons::KEBAB_HORIZONTAL_16)?;
    m.add("BOOKMARK_SLASH_24", icons::BOOKMARK_SLASH_24)?;
    m.add("TELESCOPE_FILL_24", icons::TELESCOPE_FILL_24)?;
    m.add("CROSS_REFERENCE_16", icons::CROSS_REFERENCE_16)?;
    m.add("LINK_EXTERNAL_16", icons::LINK_EXTERNAL_16)?;
    m.add("HORIZONTAL_RULE_16", icons::HORIZONTAL_RULE_16)?;
    m.add("REPO_PUSH_24", icons::REPO_PUSH_24)?;
    m.add("EYE_24", icons::EYE_24)?;
    m.add("ACCESSIBILITY_16", icons::ACCESSIBILITY_16)?;
    m.add("COLUMNS_16", icons::COLUMNS_16)?;
    m.add("GLOBE_16", icons::GLOBE_16)?;
    m.add("HEART_24", icons::HEART_24)?;
    m.add("ALERT_FILL_16", icons::ALERT_FILL_16)?;
    m.add("TRIANGLE_UP_16", icons::TRIANGLE_UP_16)?;
    m.add("REPO_LOCKED_24", icons::REPO_LOCKED_24)?;
    m.add("MOVE_TO_END_24", icons::MOVE_TO_END_24)?;
    m.add("REPO_LOCKED_16", icons::REPO_LOCKED_16)?;
    Ok(())
}
