// This file was generated. DO NOT EDIT.
use crate::{Icon, icons};

pub(super) fn find_part_3(slug: &str) -> Option<Icon> {
    match slug {
        "sparkle-fill-24" => Some(icons::SPARKLE_FILL_24),
        "exclamation-16" => Some(icons::EXCLAMATION_16),
        "filter-24" => Some(icons::FILTER_24),
        "sparkles-fill-24" => Some(icons::SPARKLES_FILL_24),
        "bug-24" => Some(icons::BUG_24),
        "x-circle-16" => Some(icons::X_CIRCLE_16),
        "clock-fill-16" => Some(icons::CLOCK_FILL_16),
        "paste-16" => Some(icons::PASTE_16),
        "mortar-board-16" => Some(icons::MORTAR_BOARD_16),
        "reply-16" => Some(icons::REPLY_16),
        "comment-discussion-16" => Some(icons::COMMENT_DISCUSSION_16),
        "flowchart-16" => Some(icons::FLOWCHART_16),
        "rss-16" => Some(icons::RSS_16),
        "logo-gist-16" => Some(icons::LOGO_GIST_16),
        "people-24" => Some(icons::PEOPLE_24),
        "cache-16" => Some(icons::CACHE_16),
        "archive-24" => Some(icons::ARCHIVE_24),
        "split-view-16" => Some(icons::SPLIT_VIEW_16),
        "file-diff-16" => Some(icons::FILE_DIFF_16),
        "circle-24" => Some(icons::CIRCLE_24),
        "lock-16" => Some(icons::LOCK_16),
        "table-24" => Some(icons::TABLE_24),
        "issue-tracks-24" => Some(icons::ISSUE_TRACKS_24),
        "discussion-outdated-16" => Some(icons::DISCUSSION_OUTDATED_16),
        "gift-24" => Some(icons::GIFT_24),
        "book-24" => Some(icons::BOOK_24),
        "megaphone-16" => Some(icons::MEGAPHONE_16),
        "check-circle-fill-24" => Some(icons::CHECK_CIRCLE_FILL_24),
        "log-24" => Some(icons::LOG_24),
        "maximize-24" => Some(icons::MAXIMIZE_24),
        "chevron-left-12" => Some(icons::CHEVRON_LEFT_12),
        "pencil-ai-16" => Some(icons::PENCIL_AI_16),
        "sort-asc-24" => Some(icons::SORT_ASC_24),
        "list-ordered-24" => Some(icons::LIST_ORDERED_24),
        "file-check-24" => Some(icons::FILE_CHECK_24),
        "flame-16" => Some(icons::FLAME_16),
        "key-16" => Some(icons::KEY_16),
        "unwrap-16" => Some(icons::UNWRAP_16),
        "check-circle-fill-12" => Some(icons::CHECK_CIRCLE_FILL_12),
        "sign-in-16" => Some(icons::SIGN_IN_16),
        "space-24" => Some(icons::SPACE_24),
        "file-removed-16" => Some(icons::FILE_REMOVED_16),
        "file-binary-24" => Some(icons::FILE_BINARY_24),
        "webhook-16" => Some(icons::WEBHOOK_16),
        "square-fill-24" => Some(icons::SQUARE_FILL_24),
        "pulse-16" => Some(icons::PULSE_16),
        "mention-16" => Some(icons::MENTION_16),
        "hubot-24" => Some(icons::HUBOT_24),
        "person-fill-16" => Some(icons::PERSON_FILL_16),
        "git-pull-request-draft-24" => Some(icons::GIT_PULL_REQUEST_DRAFT_24),
        "pivot-column-24" => Some(icons::PIVOT_COLUMN_24),
        "mute-24" => Some(icons::MUTE_24),
        "discussion-duplicate-24" => Some(icons::DISCUSSION_DUPLICATE_24),
        "feed-issue-closed-16" => Some(icons::FEED_ISSUE_CLOSED_16),
        "file-check-16" => Some(icons::FILE_CHECK_16),
        "sort-desc-16" => Some(icons::SORT_DESC_16),
        "list-unordered-16" => Some(icons::LIST_UNORDERED_16),
        "infinity-24" => Some(icons::INFINITY_24),
        "diamond-16" => Some(icons::DIAMOND_16),
        "circle-16" => Some(icons::CIRCLE_16),
        "log-16" => Some(icons::LOG_16),
        "sponsor-tiers-24" => Some(icons::SPONSOR_TIERS_24),
        "mirror-24" => Some(icons::MIRROR_24),
        "x-24" => Some(icons::X_24),
        "x-circle-fill-16" => Some(icons::X_CIRCLE_FILL_16),
        "repo-clone-24" => Some(icons::REPO_CLONE_24),
        "device-camera-24" => Some(icons::DEVICE_CAMERA_24),
        "share-24" => Some(icons::SHARE_24),
        "people-16" => Some(icons::PEOPLE_16),
        "dice-24" => Some(icons::DICE_24),
        "sort-desc-24" => Some(icons::SORT_DESC_24),
        "devices-24" => Some(icons::DEVICES_24),
        "location-16" => Some(icons::LOCATION_16),
        "copilot-96" => Some(icons::COPILOT_96),
        "light-bulb-16" => Some(icons::LIGHT_BULB_16),
        "diff-added-16" => Some(icons::DIFF_ADDED_16),
        "crosshairs-24" => Some(icons::CROSSHAIRS_24),
        "dependabot-24" => Some(icons::DEPENDABOT_24),
        "undo-16" => Some(icons::UNDO_16),
        "goal-16" => Some(icons::GOAL_16),
        "file-code-16" => Some(icons::FILE_CODE_16),
        "mirror-16" => Some(icons::MIRROR_16),
        "ellipsis-16" => Some(icons::ELLIPSIS_16),
        "dash-24" => Some(icons::DASH_24),
        "agent-24" => Some(icons::AGENT_24),
        "copilot-warning-16" => Some(icons::COPILOT_WARNING_16),
        "feed-merged-16" => Some(icons::FEED_MERGED_16),
        "sort-asc-16" => Some(icons::SORT_ASC_16),
        "bookmark-24" => Some(icons::BOOKMARK_24),
        "clock-24" => Some(icons::CLOCK_24),
        "apps-24" => Some(icons::APPS_24),
        "arrow-up-24" => Some(icons::ARROW_UP_24),
        "heart-fill-24" => Some(icons::HEART_FILL_24),
        "feed-discussion-16" => Some(icons::FEED_DISCUSSION_16),
        "tab-external-16" => Some(icons::TAB_EXTERNAL_16),
        "logo-gist-24" => Some(icons::LOGO_GIST_24),
        "bookmark-slash-fill-24" => Some(icons::BOOKMARK_SLASH_FILL_24),
        "passkey-fill-16" => Some(icons::PASSKEY_FILL_16),
        "issue-opened-16" => Some(icons::ISSUE_OPENED_16),
        "sliders-16" => Some(icons::SLIDERS_16),
        "tracked-by-closed-not-planned-16" => Some(icons::TRACKED_BY_CLOSED_NOT_PLANNED_16),
        "arrow-up-16" => Some(icons::ARROW_UP_16),
        "sparkles-fill-16" => Some(icons::SPARKLES_FILL_16),
        "issue-draft-24" => Some(icons::ISSUE_DRAFT_24),
        "boolean-on-24" => Some(icons::BOOLEAN_ON_24),
        "play-16" => Some(icons::PLAY_16),
        "file-removed-24" => Some(icons::FILE_REMOVED_24),
        "paste-24" => Some(icons::PASTE_24),
        "zoom-out-24" => Some(icons::ZOOM_OUT_24),
        "tab-24" => Some(icons::TAB_24),
        "history-16" => Some(icons::HISTORY_16),
        "dice-16" => Some(icons::DICE_16),
        "feed-pull-request-draft-16" => Some(icons::FEED_PULL_REQUEST_DRAFT_16),
        "hash-16" => Some(icons::HASH_16),
        "square-circle-24" => Some(icons::SQUARE_CIRCLE_24),
        "alert-24" => Some(icons::ALERT_24),
        "gear-16" => Some(icons::GEAR_16),
        "file-diff-24" => Some(icons::FILE_DIFF_24),
        "file-directory-symlink-24" => Some(icons::FILE_DIRECTORY_SYMLINK_24),
        "note-24" => Some(icons::NOTE_24),
        _ => None,
    }
}
