// This file was generated. DO NOT EDIT.
use crate::icons;
use pyo3::prelude::*;

pub(super) fn bind_part_1(m: &Bound<PyModule>) -> PyResult<()> {
    m.add("UNVERIFIED_24", icons::UNVERIFIED_24)?;
    m.add("ID_BADGE_24", icons::ID_BADGE_24)?;
    m.add("CHECKBOX_FILL_16", icons::CHECKBOX_FILL_16)?;
    m.add("PROJECT_24", icons::PROJECT_24)?;
    m.add("FEED_PERSON_16", icons::FEED_PERSON_16)?;
    m.add("UNMUTE_16", icons::UNMUTE_16)?;
    m.add("FILE_DIRECTORY_24", icons::FILE_DIRECTORY_24)?;
    m.add("SMILEY_NEUTRAL_24", icons::SMILEY_NEUTRAL_24)?;
    m.add("READ_16", icons::READ_16)?;
    m.add("ARROW_UP_LEFT_24", icons::ARROW_UP_LEFT_24)?;
    m.add("SHIELD_LOCK_16", icons::SHIELD_LOCK_16)?;
    m.add("HEART_16", icons::HEART_16)?;
    m.add("AI_MODEL_24", icons::AI_MODEL_24)?;
    m.add("CIRCLE_SLASH_24", icons::CIRCLE_SLASH_24)?;
    m.add("SQUIRREL_24", icons::SQUIRREL_24)?;
    m.add("SEARCH_16", icons::SEARCH_16)?;
    m.add("HEART_FILL_16", icons::HEART_FILL_16)?;
    m.add("BOOLEAN_OFF_24", icons::BOOLEAN_OFF_24)?;
    m.add("BUG_16", icons::BUG_16)?;
    m.add("CODE_16", icons::CODE_16)?;
    m.add("DISCUSSION_CLOSED_16", icons::DISCUSSION_CLOSED_16)?;
    m.add("COMPOSE_24", icons::COMPOSE_24)?;
    m.add("SHIELD_16", icons::SHIELD_16)?;
    m.add("DUPLICATE_24", icons::DUPLICATE_24)?;
    m.add("TAG_24", icons::TAG_24)?;
    m.add("ARROW_DOWN_LEFT_24", icons::ARROW_DOWN_LEFT_24)?;
    m.add("MCP_16", icons::MCP_16)?;
    m.add("ARROW_BOTH_24", icons::ARROW_BOTH_24)?;
    m.add("BEAKER_24", icons::BEAKER_24)?;
    m.add("HOME_FILL_24", icons::HOME_FILL_24)?;
    m.add("PAPERCLIP_24", icons::PAPERCLIP_24)?;
    m.add("ACCESSIBILITY_INSET_16", icons::ACCESSIBILITY_INSET_16)?;
    m.add(
        "TRACKED_BY_CLOSED_COMPLETED_24",
        icons::TRACKED_BY_CLOSED_COMPLETED_24,
    )?;
    m.add("PLUS_16", icons::PLUS_16)?;
    m.add("PAINTBRUSH_16", icons::PAINTBRUSH_16)?;
    m.add(
        "FILE_DIRECTORY_SYMLINK_16",
        icons::FILE_DIRECTORY_SYMLINK_16,
    )?;
    m.add("VIDEO_24", icons::VIDEO_24)?;
    m.add("SPONSOR_TIERS_16", icons::SPONSOR_TIERS_16)?;
    m.add("NORTH_STAR_24", icons::NORTH_STAR_24)?;
    m.add("BOOLEAN_OFF_16", icons::BOOLEAN_OFF_16)?;
    m.add("FILE_MOVED_24", icons::FILE_MOVED_24)?;
    m.add("MOVE_TO_START_16", icons::MOVE_TO_START_16)?;
    m.add("INFO_24", icons::INFO_24)?;
    m.add("CHEVRON_DOWN_12", icons::CHEVRON_DOWN_12)?;
    m.add("CODE_OF_CONDUCT_16", icons::CODE_OF_CONDUCT_16)?;
    m.add("FOLD_16", icons::FOLD_16)?;
    m.add("ROWS_24", icons::ROWS_24)?;
    m.add("PROJECT_SYMLINK_24", icons::PROJECT_SYMLINK_24)?;
    m.add("REPO_DELETE_24", icons::REPO_DELETE_24)?;
    m.add("ARROW_SWITCH_24", icons::ARROW_SWITCH_24)?;
    m.add("FILE_MOVED_16", icons::FILE_MOVED_16)?;
    m.add("LIST_UNORDERED_24", icons::LIST_UNORDERED_24)?;
    m.add("CODESCAN_16", icons::CODESCAN_16)?;
    m.add("ZOOM_OUT_16", icons::ZOOM_OUT_16)?;
    m.add("MARKDOWN_24", icons::MARKDOWN_24)?;
    m.add("MINIMIZE_24", icons::MINIMIZE_24)?;
    m.add("FILE_DIRECTORY_16", icons::FILE_DIRECTORY_16)?;
    m.add("SHIELD_LOCK_24", icons::SHIELD_LOCK_24)?;
    m.add("HORIZONTAL_RULE_24", icons::HORIZONTAL_RULE_24)?;
    m.add("SQUARE_CIRCLE_16", icons::SQUARE_CIRCLE_16)?;
    m.add("FEED_REPO_16", icons::FEED_REPO_16)?;
    m.add("FEED_PUBLIC_16", icons::FEED_PUBLIC_16)?;
    m.add("PACKAGE_16", icons::PACKAGE_16)?;
    m.add("PIVOT_COLUMN_16", icons::PIVOT_COLUMN_16)?;
    m.add("REPO_DELETED_16", icons::REPO_DELETED_16)?;
    m.add("MEGAPHONE_24", icons::MEGAPHONE_24)?;
    m.add("DIFF_REMOVED_16", icons::DIFF_REMOVED_16)?;
    m.add("GIT_BRANCH_CHECK_24", icons::GIT_BRANCH_CHECK_24)?;
    m.add("SMILEY_FROWN_16", icons::SMILEY_FROWN_16)?;
    m.add("COLUMNS_24", icons::COLUMNS_24)?;
    m.add("ISSUE_TRACKED_BY_16", icons::ISSUE_TRACKED_BY_16)?;
    m.add("APPS_16", icons::APPS_16)?;
    m.add("WORKFLOW_24", icons::WORKFLOW_24)?;
    m.add("BELL_16", icons::BELL_16)?;
    m.add("FEED_ROCKET_16", icons::FEED_ROCKET_16)?;
    m.add("UNREAD_24", icons::UNREAD_24)?;
    m.add("COMMENT_AI_24", icons::COMMENT_AI_24)?;
    m.add("DIFF_MODIFIED_16", icons::DIFF_MODIFIED_16)?;
    m.add("TROPHY_16", icons::TROPHY_16)?;
    m.add("COPILOT_48", icons::COPILOT_48)?;
    m.add("HEADING_16", icons::HEADING_16)?;
    m.add("CHECK_CIRCLE_24", icons::CHECK_CIRCLE_24)?;
    m.add("FEED_TAG_16", icons::FEED_TAG_16)?;
    m.add("FILE_DIRECTORY_FILL_24", icons::FILE_DIRECTORY_FILL_24)?;
    m.add("SERVER_16", icons::SERVER_16)?;
    m.add("SKIP_24", icons::SKIP_24)?;
    m.add("NOTE_16", icons::NOTE_16)?;
    m.add("DOT_16", icons::DOT_16)?;
    m.add("DEVICE_DESKTOP_24", icons::DEVICE_DESKTOP_24)?;
    m.add("CHEVRON_RIGHT_12", icons::CHEVRON_RIGHT_12)?;
    m.add("SPACING_MEDIUM_16", icons::SPACING_MEDIUM_16)?;
    m.add("SIGN_IN_24", icons::SIGN_IN_24)?;
    m.add("THUMBSDOWN_24", icons::THUMBSDOWN_24)?;
    m.add("ALERT_FILL_12", icons::ALERT_FILL_12)?;
    m.add("VSCODE_32", icons::VSCODE_32)?;
    m.add(
        "TRACKED_BY_CLOSED_COMPLETED_16",
        icons::TRACKED_BY_CLOSED_COMPLETED_16,
    )?;
    m.add("GRAPH_BAR_VERTICAL_16", icons::GRAPH_BAR_VERTICAL_16)?;
    m.add("CODE_SQUARE_24", icons::CODE_SQUARE_24)?;
    m.add("FILE_BADGE_24", icons::FILE_BADGE_24)?;
    m.add("ARROW_SWITCH_16", icons::ARROW_SWITCH_16)?;
    m.add("ROCKET_16", icons::ROCKET_16)?;
    m.add("CODE_24", icons::CODE_24)?;
    m.add("THUMBSUP_24", icons::THUMBSUP_24)?;
    m.add("REPO_24", icons::REPO_24)?;
    m.add("CODESCAN_CHECKMARK_16", icons::CODESCAN_CHECKMARK_16)?;
    m.add("STOP_16", icons::STOP_16)?;
    m.add("ARROW_DOWN_RIGHT_16", icons::ARROW_DOWN_RIGHT_16)?;
    m.add("HOURGLASS_16", icons::HOURGLASS_16)?;
    m.add("HOME_24", icons::HOME_24)?;
    m.add("METER_16", icons::METER_16)?;
    m.add("IMAGE_16", icons::IMAGE_16)?;
    m.add("ARROW_RIGHT_16", icons::ARROW_RIGHT_16)?;
    m.add("GIFT_16", icons::GIFT_16)?;
    m.add("EXCLAMATION_24", icons::EXCLAMATION_24)?;
    m.add("UPLOAD_24", icons::UPLOAD_24)?;
    m.add("GIT_PULL_REQUEST_16", icons::GIT_PULL_REQUEST_16)?;
    m.add("SPACING_LARGE_16", icons::SPACING_LARGE_16)?;
    m.add("TRIANGLE_RIGHT_16", icons::TRIANGLE_RIGHT_16)?;
    m.add("PERSON_ADD_24", icons::PERSON_ADD_24)?;
    m.add("SINGLE_SELECT_16", icons::SINGLE_SELECT_16)?;
    m.add("SPARKLE_24", icons::SPARKLE_24)?;
    m.add("IMAGE_24", icons::IMAGE_24)?;
    m.add("CPU_16", icons::CPU_16)?;
    m.add("DOT_24", icons::DOT_24)?;
    m.add("LOGO_GITHUB_16", icons::LOGO_GITHUB_16)?;
    m.add("SMILEY_GRIN_24", icons::SMILEY_GRIN_24)?;
    m.add("SPACING_SMALL_16", icons::SPACING_SMALL_16)?;
    m.add("MAIL_16", icons::MAIL_16)?;
    m.add("SMILEY_16", icons::SMILEY_16)?;
    m.add("KEBAB_HORIZONTAL_24", icons::KEBAB_HORIZONTAL_24)?;
    m.add("CHEVRON_UP_12", icons::CHEVRON_UP_12)?;
    m.add("PIN_SLASH_24", icons::PIN_SLASH_24)?;
    m.add("GLOBE_24", icons::GLOBE_24)?;
    m.add("REPLY_24", icons::REPLY_24)?;
    m.add("BRIEFCASE_16", icons::BRIEFCASE_16)?;
    m.add("FILE_16", icons::FILE_16)?;
    m.add("CODE_REVIEW_16", icons::CODE_REVIEW_16)?;
    m.add("NUMBER_24", icons::NUMBER_24)?;
    m.add("SQUARE_24", icons::SQUARE_24)?;
    m.add("MULTI_SELECT_24", icons::MULTI_SELECT_24)?;
    m.add("DISCUSSION_CLOSED_24", icons::DISCUSSION_CLOSED_24)?;
    m.add("SIDEBAR_COLLAPSE_24", icons::SIDEBAR_COLLAPSE_24)?;
    m.add("BROWSER_16", icons::BROWSER_16)?;
    m.add(
        "GIT_PULL_REQUEST_CLOSED_24",
        icons::GIT_PULL_REQUEST_CLOSED_24,
    )?;
    m.add("LAW_16", icons::LAW_16)?;
    m.add("DOT_FILL_24", icons::DOT_FILL_24)?;
    m.add("NUMBER_16", icons::NUMBER_16)?;
    m.add("VERIFIED_24", icons::VERIFIED_24)?;
    m.add("MARK_GITHUB_24", icons::MARK_GITHUB_24)?;
    m.add("CHEVRON_DOWN_24", icons::CHEVRON_DOWN_24)?;
    m.add("BOOKMARK_SLASH_16", icons::BOOKMARK_SLASH_16)?;
    m.add("CHEVRON_UP_16", icons::CHEVRON_UP_16)?;
    m.add("FILE_CODE_24", icons::FILE_CODE_24)?;
    m.add("KEY_24", icons::KEY_24)?;
    m.add("FLOWCHART_24", icons::FLOWCHART_24)?;
    m.add("PIN_SLASH_16", icons::PIN_SLASH_16)?;
    m.add("DEVICE_CAMERA_VIDEO_24", icons::DEVICE_CAMERA_VIDEO_24)?;
    m.add("REDO_16", icons::REDO_16)?;
    m.add("ISSUE_TRACKS_16", icons::ISSUE_TRACKS_16)?;
    m.add("DIFF_REMOVED_24", icons::DIFF_REMOVED_24)?;
    m.add("INBOX_FILL_16", icons::INBOX_FILL_16)?;
    m.add("SCREEN_NORMAL_24", icons::SCREEN_NORMAL_24)?;
    m.add("ELLIPSIS_24", icons::ELLIPSIS_24)?;
    m.add("X_12", icons::X_12)?;
    m.add("PERSON_ADD_16", icons::PERSON_ADD_16)?;
    m.add("SHARE_16", icons::SHARE_16)?;
    m.add("FILE_MEDIA_24", icons::FILE_MEDIA_24)?;
    m.add("ARROW_DOWN_24", icons::ARROW_DOWN_24)?;
    m.add("SPACING_SMALL_24", icons::SPACING_SMALL_24)?;
    m.add("DESKTOP_DOWNLOAD_24", icons::DESKTOP_DOWNLOAD_24)?;
    m.add("BELL_FILL_16", icons::BELL_FILL_16)?;
    m.add("FILE_ADDED_16", icons::FILE_ADDED_16)?;
    m.add("FILE_ADDED_24", icons::FILE_ADDED_24)?;
    m.add("CREDIT_CARD_16", icons::CREDIT_CARD_16)?;
    m.add("CHECKBOX_24", icons::CHECKBOX_24)?;
    m.add("RSS_24", icons::RSS_24)?;
    m.add("GRABBER_24", icons::GRABBER_24)?;
    m.add("UNFOLD_16", icons::UNFOLD_16)?;
    m.add("TRIANGLE_LEFT_16", icons::TRIANGLE_LEFT_16)?;
    m.add("GIT_COMPARE_16", icons::GIT_COMPARE_16)?;
    m.add("BOOKMARK_FILL_24", icons::BOOKMARK_FILL_24)?;
    m.add("ARCHIVE_16", icons::ARCHIVE_16)?;
    m.add("COMMENT_24", icons::COMMENT_24)?;
    m.add("FILTER_REMOVE_24", icons::FILTER_REMOVE_24)?;
    m.add("SUN_24", icons::SUN_24)?;
    m.add("STACK_16", icons::STACK_16)?;
    m.add("BROADCAST_24", icons::BROADCAST_24)?;
    m.add("GIT_COMPARE_24", icons::GIT_COMPARE_24)?;
    m.add("RUBY_16", icons::RUBY_16)?;
    m.add("ISSUE_REOPENED_16", icons::ISSUE_REOPENED_16)?;
    m.add("FEED_HEART_16", icons::FEED_HEART_16)?;
    m.add("STAR_16", icons::STAR_16)?;
    m.add("VERSIONS_24", icons::VERSIONS_24)?;
    m.add("CODESCAN_CHECKMARK_24", icons::CODESCAN_CHECKMARK_24)?;
    m.add("BELL_SLASH_24", icons::BELL_SLASH_24)?;
    m.add("CONTAINER_24", icons::CONTAINER_24)?;
    m.add("CHECK_16", icons::CHECK_16)?;
    m.add("ISSUE_CLOSED_16", icons::ISSUE_CLOSED_16)?;
    m.add("ZAP_16", icons::ZAP_16)?;
    m.add("SCREEN_FULL_16", icons::SCREEN_FULL_16)?;
    Ok(())
}
