# This file was generated. DO NOT EDIT.
from typing import NamedTuple, Final

class Icon(NamedTuple):
    svg: str
    slug: str

def get_icon(slug: str) -> Icon | None: ...

FILE_ZIP_16: Final[Icon] = ...
PERSON_16: Final[Icon] = ...
AGENT_16: Final[Icon] = ...
REPO_FORKED_24: Final[Icon] = ...
FISCAL_HOST_24: Final[Icon] = ...
TOOLS_16: Final[Icon] = ...
GIT_PULL_REQUEST_24: Final[Icon] = ...
BOOKMARK_16: Final[Icon] = ...
THUMBSDOWN_16: Final[Icon] = ...
COPILOT_24: Final[Icon] = ...
PLUS_24: Final[Icon] = ...
UNLOCK_16: Final[Icon] = ...
FILE_SYMLINK_FILE_24: Final[Icon] = ...
TOOLS_24: Final[Icon] = ...
LOOP_24: Final[Icon] = ...
CACHE_24: Final[Icon] = ...
CODESCAN_24: Final[Icon] = ...
INFINITY_16: Final[Icon] = ...
FEED_ISSUE_DRAFT_16: Final[Icon] = ...
TRIANGLE_RIGHT_24: Final[Icon] = ...
UNDO_24: Final[Icon] = ...
DOWNLOAD_16: Final[Icon] = ...
KEY_ASTERISK_16: Final[Icon] = ...
TABLE_16: Final[Icon] = ...
FEED_TROPHY_16: Final[Icon] = ...
FOLD_24: Final[Icon] = ...
MOON_24: Final[Icon] = ...
LAW_24: Final[Icon] = ...
FILE_MEDIA_16: Final[Icon] = ...
MAXIMIZE_16: Final[Icon] = ...
COMMAND_PALETTE_24: Final[Icon] = ...
MILESTONE_24: Final[Icon] = ...
SPARKLE_16: Final[Icon] = ...
X_CIRCLE_24: Final[Icon] = ...
SMILEY_NEUTRAL_16: Final[Icon] = ...
UNLOCK_24: Final[Icon] = ...
METER_24: Final[Icon] = ...
HOME_16: Final[Icon] = ...
FILTER_REMOVE_16: Final[Icon] = ...
UPLOAD_16: Final[Icon] = ...
MOVE_TO_TOP_16: Final[Icon] = ...
STOPWATCH_24: Final[Icon] = ...
DIFF_MODIFIED_24: Final[Icon] = ...
DASH_16: Final[Icon] = ...
FILE_BADGE_16: Final[Icon] = ...
PLUG_24: Final[Icon] = ...
PROJECT_TEMPLATE_16: Final[Icon] = ...
UNVERIFIED_16: Final[Icon] = ...
PACKAGE_DEPENDENCIES_24: Final[Icon] = ...
CIRCLE_SLASH_16: Final[Icon] = ...
DEVICE_MOBILE_16: Final[Icon] = ...
LOOP_16: Final[Icon] = ...
BEAKER_16: Final[Icon] = ...
STAR_FILL_16: Final[Icon] = ...
PERSON_24: Final[Icon] = ...
CHECK_24: Final[Icon] = ...
REDO_24: Final[Icon] = ...
PROJECT_TEMPLATE_24: Final[Icon] = ...
ORGANIZATION_24: Final[Icon] = ...
BROADCAST_16: Final[Icon] = ...
MOVE_TO_BOTTOM_16: Final[Icon] = ...
TROPHY_24: Final[Icon] = ...
MILESTONE_16: Final[Icon] = ...
INFO_16: Final[Icon] = ...
COMPOSE_16: Final[Icon] = ...
SYNC_24: Final[Icon] = ...
DEVICES_16: Final[Icon] = ...
MCP_24: Final[Icon] = ...
SQUIRREL_16: Final[Icon] = ...
ITALIC_16: Final[Icon] = ...
SYNC_16: Final[Icon] = ...
DEVICE_MOBILE_24: Final[Icon] = ...
ARROW_UP_LEFT_16: Final[Icon] = ...
REPO_CLONE_16: Final[Icon] = ...
READ_24: Final[Icon] = ...
CHECKBOX_16: Final[Icon] = ...
COPY_24: Final[Icon] = ...
ARROW_LEFT_24: Final[Icon] = ...
SIDEBAR_EXPAND_24: Final[Icon] = ...
CHEVRON_LEFT_16: Final[Icon] = ...
MOVE_TO_END_16: Final[Icon] = ...
MORTAR_BOARD_24: Final[Icon] = ...
FEED_PULL_REQUEST_CLOSED_16: Final[Icon] = ...
GRABBER_16: Final[Icon] = ...
PAPERCLIP_16: Final[Icon] = ...
GIT_MERGE_16: Final[Icon] = ...
DIFF_ADDED_24: Final[Icon] = ...
NORTH_STAR_16: Final[Icon] = ...
CALENDAR_24: Final[Icon] = ...
TAB_16: Final[Icon] = ...
MARK_GITHUB_16: Final[Icon] = ...
SCREEN_NORMAL_16: Final[Icon] = ...
BOLD_16: Final[Icon] = ...
FILE_24: Final[Icon] = ...
PENCIL_24: Final[Icon] = ...
CONTAINER_16: Final[Icon] = ...
LINK_24: Final[Icon] = ...
TERMINAL_24: Final[Icon] = ...
SPLIT_VIEW_24: Final[Icon] = ...
BOOKMARK_SLASH_FILL_16: Final[Icon] = ...
BOOK_16: Final[Icon] = ...
BELL_FILL_24: Final[Icon] = ...
PULSE_24: Final[Icon] = ...
REPO_PULL_16: Final[Icon] = ...
FOLD_DOWN_24: Final[Icon] = ...
CHEVRON_RIGHT_24: Final[Icon] = ...
MINIMIZE_16: Final[Icon] = ...
FILE_SUBMODULE_16: Final[Icon] = ...
GIT_BRANCH_16: Final[Icon] = ...
FILE_BINARY_16: Final[Icon] = ...
REPO_16: Final[Icon] = ...
PAPER_AIRPLANE_24: Final[Icon] = ...
SHARE_ANDROID_16: Final[Icon] = ...
FLAME_24: Final[Icon] = ...
HOME_FILL_16: Final[Icon] = ...
CHEVRON_LEFT_24: Final[Icon] = ...
SHIELD_CHECK_24: Final[Icon] = ...
VSCODE_16: Final[Icon] = ...
SEARCH_24: Final[Icon] = ...
CLOCK_16: Final[Icon] = ...
CLOCK_FILL_24: Final[Icon] = ...
ARROW_LEFT_16: Final[Icon] = ...
FEED_STAR_16: Final[Icon] = ...
COMMAND_PALETTE_16: Final[Icon] = ...
ARROW_BOTH_16: Final[Icon] = ...
GIT_MERGE_24: Final[Icon] = ...
STAR_FILL_24: Final[Icon] = ...
BELL_24: Final[Icon] = ...
RUBY_24: Final[Icon] = ...
PACKAGE_24: Final[Icon] = ...
SKIP_FILL_24: Final[Icon] = ...
GRAPH_BAR_HORIZONTAL_24: Final[Icon] = ...
SKIP_FILL_16: Final[Icon] = ...
CROSS_REFERENCE_24: Final[Icon] = ...
HEADING_24: Final[Icon] = ...
UNLINK_24: Final[Icon] = ...
ROWS_16: Final[Icon] = ...
QUOTE_16: Final[Icon] = ...
NO_ENTRY_24: Final[Icon] = ...
QUOTE_24: Final[Icon] = ...
AI_MODEL_16: Final[Icon] = ...
PROJECT_SYMLINK_16: Final[Icon] = ...
MOVE_TO_BOTTOM_24: Final[Icon] = ...
INBOX_16: Final[Icon] = ...
SMILEY_FROWN_24: Final[Icon] = ...
FILE_ZIP_24: Final[Icon] = ...
ACCESSIBILITY_INSET_24: Final[Icon] = ...
ISSUE_OPENED_24: Final[Icon] = ...
STACK_24: Final[Icon] = ...
FOLD_DOWN_16: Final[Icon] = ...
QUESTION_24: Final[Icon] = ...
CHEVRON_UP_24: Final[Icon] = ...
BLOCKED_24: Final[Icon] = ...
MOON_16: Final[Icon] = ...
ZOOM_IN_24: Final[Icon] = ...
ROCKET_24: Final[Icon] = ...
TRIANGLE_DOWN_16: Final[Icon] = ...
ARROW_DOWN_16: Final[Icon] = ...
CHECKLIST_16: Final[Icon] = ...
REL_FILE_PATH_24: Final[Icon] = ...
EYE_16: Final[Icon] = ...
UNWRAP_24: Final[Icon] = ...
TERMINAL_16: Final[Icon] = ...
X_CIRCLE_FILL_24: Final[Icon] = ...
GIT_COMMIT_24: Final[Icon] = ...
FOLD_UP_16: Final[Icon] = ...
FEED_PLUS_16: Final[Icon] = ...
GEAR_24: Final[Icon] = ...
VSCODE_48: Final[Icon] = ...
TASKLIST_24: Final[Icon] = ...
DOT_FILL_16: Final[Icon] = ...
DESKTOP_DOWNLOAD_16: Final[Icon] = ...
LOCATION_24: Final[Icon] = ...
INBOX_FILL_24: Final[Icon] = ...
PASSKEY_FILL_24: Final[Icon] = ...
NODE_16: Final[Icon] = ...
GIT_BRANCH_CHECK_16: Final[Icon] = ...
FISCAL_HOST_16: Final[Icon] = ...
SHIELD_CHECK_16: Final[Icon] = ...
FILE_DIRECTORY_OPEN_FILL_16: Final[Icon] = ...
MENTION_24: Final[Icon] = ...
DEVICE_DESKTOP_16: Final[Icon] = ...
ALERT_FILL_24: Final[Icon] = ...
PAUSE_16: Final[Icon] = ...
MUTE_16: Final[Icon] = ...
TRIANGLE_UP_24: Final[Icon] = ...
PROJECT_ROADMAP_24: Final[Icon] = ...
STOPWATCH_16: Final[Icon] = ...
ORGANIZATION_16: Final[Icon] = ...
ARROW_DOWN_RIGHT_24: Final[Icon] = ...
ALERT_16: Final[Icon] = ...
WORKFLOW_16: Final[Icon] = ...
REL_FILE_PATH_16: Final[Icon] = ...
DIFF_RENAMED_16: Final[Icon] = ...
GIT_MERGE_QUEUE_24: Final[Icon] = ...
VERIFIED_16: Final[Icon] = ...
QUESTION_16: Final[Icon] = ...
COPY_16: Final[Icon] = ...
PAPER_AIRPLANE_16: Final[Icon] = ...
SHIELD_SLASH_16: Final[Icon] = ...
UNVERIFIED_24: Final[Icon] = ...
ID_BADGE_24: Final[Icon] = ...
CHECKBOX_FILL_16: Final[Icon] = ...
PROJECT_24: Final[Icon] = ...
FEED_PERSON_16: Final[Icon] = ...
UNMUTE_16: Final[Icon] = ...
FILE_DIRECTORY_24: Final[Icon] = ...
SMILEY_NEUTRAL_24: Final[Icon] = ...
READ_16: Final[Icon] = ...
ARROW_UP_LEFT_24: Final[Icon] = ...
SHIELD_LOCK_16: Final[Icon] = ...
HEART_16: Final[Icon] = ...
AI_MODEL_24: Final[Icon] = ...
CIRCLE_SLASH_24: Final[Icon] = ...
SQUIRREL_24: Final[Icon] = ...
SEARCH_16: Final[Icon] = ...
HEART_FILL_16: Final[Icon] = ...
BOOLEAN_OFF_24: Final[Icon] = ...
BUG_16: Final[Icon] = ...
CODE_16: Final[Icon] = ...
DISCUSSION_CLOSED_16: Final[Icon] = ...
COMPOSE_24: Final[Icon] = ...
SHIELD_16: Final[Icon] = ...
DUPLICATE_24: Final[Icon] = ...
TAG_24: Final[Icon] = ...
ARROW_DOWN_LEFT_24: Final[Icon] = ...
MCP_16: Final[Icon] = ...
ARROW_BOTH_24: Final[Icon] = ...
BEAKER_24: Final[Icon] = ...
HOME_FILL_24: Final[Icon] = ...
PAPERCLIP_24: Final[Icon] = ...
ACCESSIBILITY_INSET_16: Final[Icon] = ...
TRACKED_BY_CLOSED_COMPLETED_24: Final[Icon] = ...
PLUS_16: Final[Icon] = ...
PAINTBRUSH_16: Final[Icon] = ...
FILE_DIRECTORY_SYMLINK_16: Final[Icon] = ...
VIDEO_24: Final[Icon] = ...
SPONSOR_TIERS_16: Final[Icon] = ...
NORTH_STAR_24: Final[Icon] = ...
BOOLEAN_OFF_16: Final[Icon] = ...
FILE_MOVED_24: Final[Icon] = ...
MOVE_TO_START_16: Final[Icon] = ...
INFO_24: Final[Icon] = ...
CHEVRON_DOWN_12: Final[Icon] = ...
CODE_OF_CONDUCT_16: Final[Icon] = ...
FOLD_16: Final[Icon] = ...
ROWS_24: Final[Icon] = ...
PROJECT_SYMLINK_24: Final[Icon] = ...
REPO_DELETE_24: Final[Icon] = ...
ARROW_SWITCH_24: Final[Icon] = ...
FILE_MOVED_16: Final[Icon] = ...
LIST_UNORDERED_24: Final[Icon] = ...
CODESCAN_16: Final[Icon] = ...
ZOOM_OUT_16: Final[Icon] = ...
MARKDOWN_24: Final[Icon] = ...
MINIMIZE_24: Final[Icon] = ...
FILE_DIRECTORY_16: Final[Icon] = ...
SHIELD_LOCK_24: Final[Icon] = ...
HORIZONTAL_RULE_24: Final[Icon] = ...
SQUARE_CIRCLE_16: Final[Icon] = ...
FEED_REPO_16: Final[Icon] = ...
FEED_PUBLIC_16: Final[Icon] = ...
PACKAGE_16: Final[Icon] = ...
PIVOT_COLUMN_16: Final[Icon] = ...
REPO_DELETED_16: Final[Icon] = ...
MEGAPHONE_24: Final[Icon] = ...
DIFF_REMOVED_16: Final[Icon] = ...
GIT_BRANCH_CHECK_24: Final[Icon] = ...
SMILEY_FROWN_16: Final[Icon] = ...
COLUMNS_24: Final[Icon] = ...
ISSUE_TRACKED_BY_16: Final[Icon] = ...
APPS_16: Final[Icon] = ...
WORKFLOW_24: Final[Icon] = ...
BELL_16: Final[Icon] = ...
FEED_ROCKET_16: Final[Icon] = ...
UNREAD_24: Final[Icon] = ...
COMMENT_AI_24: Final[Icon] = ...
DIFF_MODIFIED_16: Final[Icon] = ...
TROPHY_16: Final[Icon] = ...
COPILOT_48: Final[Icon] = ...
HEADING_16: Final[Icon] = ...
CHECK_CIRCLE_24: Final[Icon] = ...
FEED_TAG_16: Final[Icon] = ...
FILE_DIRECTORY_FILL_24: Final[Icon] = ...
SERVER_16: Final[Icon] = ...
SKIP_24: Final[Icon] = ...
NOTE_16: Final[Icon] = ...
DOT_16: Final[Icon] = ...
DEVICE_DESKTOP_24: Final[Icon] = ...
CHEVRON_RIGHT_12: Final[Icon] = ...
SPACING_MEDIUM_16: Final[Icon] = ...
SIGN_IN_24: Final[Icon] = ...
THUMBSDOWN_24: Final[Icon] = ...
ALERT_FILL_12: Final[Icon] = ...
VSCODE_32: Final[Icon] = ...
TRACKED_BY_CLOSED_COMPLETED_16: Final[Icon] = ...
GRAPH_BAR_VERTICAL_16: Final[Icon] = ...
CODE_SQUARE_24: Final[Icon] = ...
FILE_BADGE_24: Final[Icon] = ...
ARROW_SWITCH_16: Final[Icon] = ...
ROCKET_16: Final[Icon] = ...
CODE_24: Final[Icon] = ...
THUMBSUP_24: Final[Icon] = ...
REPO_24: Final[Icon] = ...
CODESCAN_CHECKMARK_16: Final[Icon] = ...
STOP_16: Final[Icon] = ...
ARROW_DOWN_RIGHT_16: Final[Icon] = ...
HOURGLASS_16: Final[Icon] = ...
HOME_24: Final[Icon] = ...
METER_16: Final[Icon] = ...
IMAGE_16: Final[Icon] = ...
ARROW_RIGHT_16: Final[Icon] = ...
GIFT_16: Final[Icon] = ...
EXCLAMATION_24: Final[Icon] = ...
UPLOAD_24: Final[Icon] = ...
GIT_PULL_REQUEST_16: Final[Icon] = ...
SPACING_LARGE_16: Final[Icon] = ...
TRIANGLE_RIGHT_16: Final[Icon] = ...
PERSON_ADD_24: Final[Icon] = ...
SINGLE_SELECT_16: Final[Icon] = ...
SPARKLE_24: Final[Icon] = ...
IMAGE_24: Final[Icon] = ...
CPU_16: Final[Icon] = ...
DOT_24: Final[Icon] = ...
LOGO_GITHUB_16: Final[Icon] = ...
SMILEY_GRIN_24: Final[Icon] = ...
SPACING_SMALL_16: Final[Icon] = ...
MAIL_16: Final[Icon] = ...
SMILEY_16: Final[Icon] = ...
KEBAB_HORIZONTAL_24: Final[Icon] = ...
CHEVRON_UP_12: Final[Icon] = ...
PIN_SLASH_24: Final[Icon] = ...
GLOBE_24: Final[Icon] = ...
REPLY_24: Final[Icon] = ...
BRIEFCASE_16: Final[Icon] = ...
FILE_16: Final[Icon] = ...
CODE_REVIEW_16: Final[Icon] = ...
NUMBER_24: Final[Icon] = ...
SQUARE_24: Final[Icon] = ...
MULTI_SELECT_24: Final[Icon] = ...
DISCUSSION_CLOSED_24: Final[Icon] = ...
SIDEBAR_COLLAPSE_24: Final[Icon] = ...
BROWSER_16: Final[Icon] = ...
GIT_PULL_REQUEST_CLOSED_24: Final[Icon] = ...
LAW_16: Final[Icon] = ...
DOT_FILL_24: Final[Icon] = ...
NUMBER_16: Final[Icon] = ...
VERIFIED_24: Final[Icon] = ...
MARK_GITHUB_24: Final[Icon] = ...
CHEVRON_DOWN_24: Final[Icon] = ...
BOOKMARK_SLASH_16: Final[Icon] = ...
CHEVRON_UP_16: Final[Icon] = ...
FILE_CODE_24: Final[Icon] = ...
KEY_24: Final[Icon] = ...
FLOWCHART_24: Final[Icon] = ...
PIN_SLASH_16: Final[Icon] = ...
DEVICE_CAMERA_VIDEO_24: Final[Icon] = ...
REDO_16: Final[Icon] = ...
ISSUE_TRACKS_16: Final[Icon] = ...
DIFF_REMOVED_24: Final[Icon] = ...
INBOX_FILL_16: Final[Icon] = ...
SCREEN_NORMAL_24: Final[Icon] = ...
ELLIPSIS_24: Final[Icon] = ...
X_12: Final[Icon] = ...
PERSON_ADD_16: Final[Icon] = ...
SHARE_16: Final[Icon] = ...
FILE_MEDIA_24: Final[Icon] = ...
ARROW_DOWN_24: Final[Icon] = ...
SPACING_SMALL_24: Final[Icon] = ...
DESKTOP_DOWNLOAD_24: Final[Icon] = ...
BELL_FILL_16: Final[Icon] = ...
FILE_ADDED_16: Final[Icon] = ...
FILE_ADDED_24: Final[Icon] = ...
CREDIT_CARD_16: Final[Icon] = ...
CHECKBOX_24: Final[Icon] = ...
RSS_24: Final[Icon] = ...
GRABBER_24: Final[Icon] = ...
UNFOLD_16: Final[Icon] = ...
TRIANGLE_LEFT_16: Final[Icon] = ...
GIT_COMPARE_16: Final[Icon] = ...
BOOKMARK_FILL_24: Final[Icon] = ...
ARCHIVE_16: Final[Icon] = ...
COMMENT_24: Final[Icon] = ...
FILTER_REMOVE_24: Final[Icon] = ...
SUN_24: Final[Icon] = ...
STACK_16: Final[Icon] = ...
BROADCAST_24: Final[Icon] = ...
GIT_COMPARE_24: Final[Icon] = ...
RUBY_16: Final[Icon] = ...
ISSUE_REOPENED_16: Final[Icon] = ...
FEED_HEART_16: Final[Icon] = ...
STAR_16: Final[Icon] = ...
VERSIONS_24: Final[Icon] = ...
CODESCAN_CHECKMARK_24: Final[Icon] = ...
BELL_SLASH_24: Final[Icon] = ...
CONTAINER_24: Final[Icon] = ...
CHECK_16: Final[Icon] = ...
ISSUE_CLOSED_16: Final[Icon] = ...
ZAP_16: Final[Icon] = ...
SCREEN_FULL_16: Final[Icon] = ...
WRAP_24: Final[Icon] = ...
SIGN_OUT_16: Final[Icon] = ...
DIFF_RENAMED_24: Final[Icon] = ...
LIST_ORDERED_16: Final[Icon] = ...
REPORT_16: Final[Icon] = ...
TRASH_24: Final[Icon] = ...
SMILEY_GRIN_16: Final[Icon] = ...
STRIKETHROUGH_16: Final[Icon] = ...
DISCUSSION_DUPLICATE_16: Final[Icon] = ...
FILE_SYMLINK_FILE_16: Final[Icon] = ...
UNFOLD_24: Final[Icon] = ...
PACKAGE_DEPENDENTS_24: Final[Icon] = ...
TRIANGLE_DOWN_24: Final[Icon] = ...
SHIELD_SLASH_24: Final[Icon] = ...
BOOLEAN_ON_16: Final[Icon] = ...
ITERATIONS_16: Final[Icon] = ...
DUPLICATE_16: Final[Icon] = ...
DEVICE_CAMERA_16: Final[Icon] = ...
CREDIT_CARD_24: Final[Icon] = ...
PLUS_CIRCLE_24: Final[Icon] = ...
GIT_COMMIT_16: Final[Icon] = ...
SHIELD_X_24: Final[Icon] = ...
SINGLE_SELECT_24: Final[Icon] = ...
ZAP_24: Final[Icon] = ...
PAUSE_24: Final[Icon] = ...
SHARE_ANDROID_24: Final[Icon] = ...
REPO_PULL_24: Final[Icon] = ...
LIGHT_BULB_24: Final[Icon] = ...
BRIEFCASE_24: Final[Icon] = ...
FILE_DIRECTORY_OPEN_FILL_24: Final[Icon] = ...
TELESCOPE_16: Final[Icon] = ...
CLOUD_OFFLINE_16: Final[Icon] = ...
FOCUS_CENTER_24: Final[Icon] = ...
SIDEBAR_EXPAND_16: Final[Icon] = ...
MARKDOWN_16: Final[Icon] = ...
CODE_SQUARE_16: Final[Icon] = ...
LOGO_GITHUB_24: Final[Icon] = ...
DIFF_24: Final[Icon] = ...
MAIL_24: Final[Icon] = ...
CHEVRON_RIGHT_16: Final[Icon] = ...
SUN_16: Final[Icon] = ...
CLOUD_16: Final[Icon] = ...
MOVE_TO_START_24: Final[Icon] = ...
ISSUE_TRACKED_BY_24: Final[Icon] = ...
FEED_FORKED_16: Final[Icon] = ...
EYE_CLOSED_24: Final[Icon] = ...
HASH_24: Final[Icon] = ...
COMMENT_16: Final[Icon] = ...
SMILEY_24: Final[Icon] = ...
GOAL_24: Final[Icon] = ...
ISSUE_REOPENED_24: Final[Icon] = ...
REPO_PUSH_16: Final[Icon] = ...
PLAY_24: Final[Icon] = ...
DOWNLOAD_24: Final[Icon] = ...
ITERATIONS_24: Final[Icon] = ...
THREE_BARS_16: Final[Icon] = ...
ISSUE_DRAFT_16: Final[Icon] = ...
SPACING_MEDIUM_24: Final[Icon] = ...
TRACKED_BY_CLOSED_NOT_PLANNED_24: Final[Icon] = ...
SIDEBAR_COLLAPSE_16: Final[Icon] = ...
NO_ENTRY_FILL_12: Final[Icon] = ...
SLIDERS_24: Final[Icon] = ...
ISSUE_CLOSED_24: Final[Icon] = ...
PERSON_FILL_24: Final[Icon] = ...
GRAPH_16: Final[Icon] = ...
REPO_TEMPLATE_16: Final[Icon] = ...
ZOOM_IN_16: Final[Icon] = ...
BELL_SLASH_16: Final[Icon] = ...
UNLINK_16: Final[Icon] = ...
CLOUD_OFFLINE_24: Final[Icon] = ...
ARROW_DOWN_LEFT_16: Final[Icon] = ...
STAR_24: Final[Icon] = ...
TASKLIST_16: Final[Icon] = ...
CODESPACES_16: Final[Icon] = ...
TAB_EXTERNAL_24: Final[Icon] = ...
REPORT_24: Final[Icon] = ...
FEED_ISSUE_OPEN_16: Final[Icon] = ...
BLOCKED_16: Final[Icon] = ...
PACKAGE_DEPENDENCIES_16: Final[Icon] = ...
ARROW_RIGHT_24: Final[Icon] = ...
PLUS_CIRCLE_16: Final[Icon] = ...
FILE_DIRECTORY_FILL_16: Final[Icon] = ...
SMILEY_FRUSTRATED_16: Final[Icon] = ...
SERVER_24: Final[Icon] = ...
CLOUD_24: Final[Icon] = ...
TAG_16: Final[Icon] = ...
THUMBSUP_16: Final[Icon] = ...
MULTI_SELECT_16: Final[Icon] = ...
TELESCOPE_FILL_16: Final[Icon] = ...
SIGN_OUT_24: Final[Icon] = ...
TELESCOPE_24: Final[Icon] = ...
PENCIL_AI_24: Final[Icon] = ...
PACKAGE_DEPENDENTS_16: Final[Icon] = ...
NODE_24: Final[Icon] = ...
TYPOGRAPHY_16: Final[Icon] = ...
SQUARE_FILL_16: Final[Icon] = ...
COPILOT_16: Final[Icon] = ...
GRAPH_BAR_VERTICAL_24: Final[Icon] = ...
REPO_FORKED_16: Final[Icon] = ...
MOVE_TO_TOP_24: Final[Icon] = ...
DIFF_IGNORED_16: Final[Icon] = ...
DIFF_IGNORED_24: Final[Icon] = ...
X_16: Final[Icon] = ...
ID_BADGE_16: Final[Icon] = ...
PLUG_16: Final[Icon] = ...
X_CIRCLE_FILL_12: Final[Icon] = ...
VERSIONS_16: Final[Icon] = ...
TRIANGLE_LEFT_24: Final[Icon] = ...
SCREEN_FULL_24: Final[Icon] = ...
COMMENT_DISCUSSION_24: Final[Icon] = ...
CHECKLIST_24: Final[Icon] = ...
SKIP_16: Final[Icon] = ...
DIAMOND_24: Final[Icon] = ...
CHECKBOX_FILL_24: Final[Icon] = ...
FILTER_16: Final[Icon] = ...
PROJECT_16: Final[Icon] = ...
BOOKMARK_FILLED_16: Final[Icon] = ...
FOLD_UP_24: Final[Icon] = ...
NO_ENTRY_16: Final[Icon] = ...
REPO_TEMPLATE_24: Final[Icon] = ...
HISTORY_24: Final[Icon] = ...
ACCESSIBILITY_24: Final[Icon] = ...
ARROW_UP_RIGHT_16: Final[Icon] = ...
CALENDAR_16: Final[Icon] = ...
FOCUS_CENTER_16: Final[Icon] = ...
CHECK_CIRCLE_FILL_16: Final[Icon] = ...
LOCK_24: Final[Icon] = ...
HUBOT_16: Final[Icon] = ...
VIDEO_16: Final[Icon] = ...
STRIKETHROUGH_24: Final[Icon] = ...
FEED_PULL_REQUEST_OPEN_16: Final[Icon] = ...
THREE_BARS_24: Final[Icon] = ...
SPACE_16: Final[Icon] = ...
CHEVRON_DOWN_16: Final[Icon] = ...
DATABASE_24: Final[Icon] = ...
ARROW_UP_RIGHT_24: Final[Icon] = ...
KEY_ASTERISK_24: Final[Icon] = ...
GIT_PULL_REQUEST_CLOSED_16: Final[Icon] = ...
GRAPH_24: Final[Icon] = ...
CODE_OF_CONDUCT_24: Final[Icon] = ...
CPU_24: Final[Icon] = ...
BOLD_24: Final[Icon] = ...
PROJECT_ROADMAP_16: Final[Icon] = ...
SPARKLE_FILL_16: Final[Icon] = ...
PENCIL_16: Final[Icon] = ...
PIN_24: Final[Icon] = ...
EYE_CLOSED_16: Final[Icon] = ...
CHECK_CIRCLE_16: Final[Icon] = ...
LINK_EXTERNAL_24: Final[Icon] = ...
TYPOGRAPHY_24: Final[Icon] = ...
WRAP_16: Final[Icon] = ...
HOURGLASS_24: Final[Icon] = ...
DEVICE_CAMERA_VIDEO_16: Final[Icon] = ...
GIT_MERGE_QUEUE_16: Final[Icon] = ...
TRASH_16: Final[Icon] = ...
DIFF_16: Final[Icon] = ...
DEPENDABOT_16: Final[Icon] = ...
CODESPACES_24: Final[Icon] = ...
BROWSER_24: Final[Icon] = ...
PIN_16: Final[Icon] = ...
SQUARE_16: Final[Icon] = ...
DISCUSSION_OUTDATED_24: Final[Icon] = ...
SHIELD_24: Final[Icon] = ...
UNMUTE_24: Final[Icon] = ...
STOP_24: Final[Icon] = ...
SMILEY_FRUSTRATED_24: Final[Icon] = ...
UNREAD_16: Final[Icon] = ...
GIT_PULL_REQUEST_DRAFT_16: Final[Icon] = ...
PAINTBRUSH_24: Final[Icon] = ...
GIT_BRANCH_24: Final[Icon] = ...
COMMENT_AI_16: Final[Icon] = ...
INBOX_24: Final[Icon] = ...
GRAPH_BAR_HORIZONTAL_16: Final[Icon] = ...
FILE_SUBMODULE_24: Final[Icon] = ...
DATABASE_16: Final[Icon] = ...
CODE_REVIEW_24: Final[Icon] = ...
SHIELD_X_16: Final[Icon] = ...
FEED_ISSUE_REOPEN_16: Final[Icon] = ...
CROSSHAIRS_16: Final[Icon] = ...
COPILOT_ERROR_16: Final[Icon] = ...
ITALIC_24: Final[Icon] = ...
LINK_16: Final[Icon] = ...
SPACING_LARGE_24: Final[Icon] = ...
KEBAB_HORIZONTAL_16: Final[Icon] = ...
BOOKMARK_SLASH_24: Final[Icon] = ...
TELESCOPE_FILL_24: Final[Icon] = ...
CROSS_REFERENCE_16: Final[Icon] = ...
LINK_EXTERNAL_16: Final[Icon] = ...
HORIZONTAL_RULE_16: Final[Icon] = ...
REPO_PUSH_24: Final[Icon] = ...
EYE_24: Final[Icon] = ...
ACCESSIBILITY_16: Final[Icon] = ...
COLUMNS_16: Final[Icon] = ...
GLOBE_16: Final[Icon] = ...
HEART_24: Final[Icon] = ...
ALERT_FILL_16: Final[Icon] = ...
TRIANGLE_UP_16: Final[Icon] = ...
REPO_LOCKED_24: Final[Icon] = ...
MOVE_TO_END_24: Final[Icon] = ...
REPO_LOCKED_16: Final[Icon] = ...
SPARKLE_FILL_24: Final[Icon] = ...
EXCLAMATION_16: Final[Icon] = ...
FILTER_24: Final[Icon] = ...
SPARKLES_FILL_24: Final[Icon] = ...
BUG_24: Final[Icon] = ...
X_CIRCLE_16: Final[Icon] = ...
CLOCK_FILL_16: Final[Icon] = ...
PASTE_16: Final[Icon] = ...
MORTAR_BOARD_16: Final[Icon] = ...
REPLY_16: Final[Icon] = ...
COMMENT_DISCUSSION_16: Final[Icon] = ...
FLOWCHART_16: Final[Icon] = ...
RSS_16: Final[Icon] = ...
LOGO_GIST_16: Final[Icon] = ...
PEOPLE_24: Final[Icon] = ...
CACHE_16: Final[Icon] = ...
ARCHIVE_24: Final[Icon] = ...
SPLIT_VIEW_16: Final[Icon] = ...
FILE_DIFF_16: Final[Icon] = ...
CIRCLE_24: Final[Icon] = ...
LOCK_16: Final[Icon] = ...
TABLE_24: Final[Icon] = ...
ISSUE_TRACKS_24: Final[Icon] = ...
DISCUSSION_OUTDATED_16: Final[Icon] = ...
GIFT_24: Final[Icon] = ...
BOOK_24: Final[Icon] = ...
MEGAPHONE_16: Final[Icon] = ...
CHECK_CIRCLE_FILL_24: Final[Icon] = ...
LOG_24: Final[Icon] = ...
MAXIMIZE_24: Final[Icon] = ...
CHEVRON_LEFT_12: Final[Icon] = ...
PENCIL_AI_16: Final[Icon] = ...
SORT_ASC_24: Final[Icon] = ...
LIST_ORDERED_24: Final[Icon] = ...
FILE_CHECK_24: Final[Icon] = ...
FLAME_16: Final[Icon] = ...
KEY_16: Final[Icon] = ...
UNWRAP_16: Final[Icon] = ...
CHECK_CIRCLE_FILL_12: Final[Icon] = ...
SIGN_IN_16: Final[Icon] = ...
SPACE_24: Final[Icon] = ...
FILE_REMOVED_16: Final[Icon] = ...
FILE_BINARY_24: Final[Icon] = ...
WEBHOOK_16: Final[Icon] = ...
SQUARE_FILL_24: Final[Icon] = ...
PULSE_16: Final[Icon] = ...
MENTION_16: Final[Icon] = ...
HUBOT_24: Final[Icon] = ...
PERSON_FILL_16: Final[Icon] = ...
GIT_PULL_REQUEST_DRAFT_24: Final[Icon] = ...
PIVOT_COLUMN_24: Final[Icon] = ...
MUTE_24: Final[Icon] = ...
DISCUSSION_DUPLICATE_24: Final[Icon] = ...
FEED_ISSUE_CLOSED_16: Final[Icon] = ...
FILE_CHECK_16: Final[Icon] = ...
SORT_DESC_16: Final[Icon] = ...
LIST_UNORDERED_16: Final[Icon] = ...
INFINITY_24: Final[Icon] = ...
DIAMOND_16: Final[Icon] = ...
CIRCLE_16: Final[Icon] = ...
LOG_16: Final[Icon] = ...
SPONSOR_TIERS_24: Final[Icon] = ...
MIRROR_24: Final[Icon] = ...
X_24: Final[Icon] = ...
X_CIRCLE_FILL_16: Final[Icon] = ...
REPO_CLONE_24: Final[Icon] = ...
DEVICE_CAMERA_24: Final[Icon] = ...
SHARE_24: Final[Icon] = ...
PEOPLE_16: Final[Icon] = ...
DICE_24: Final[Icon] = ...
SORT_DESC_24: Final[Icon] = ...
DEVICES_24: Final[Icon] = ...
LOCATION_16: Final[Icon] = ...
COPILOT_96: Final[Icon] = ...
LIGHT_BULB_16: Final[Icon] = ...
DIFF_ADDED_16: Final[Icon] = ...
CROSSHAIRS_24: Final[Icon] = ...
DEPENDABOT_24: Final[Icon] = ...
UNDO_16: Final[Icon] = ...
GOAL_16: Final[Icon] = ...
FILE_CODE_16: Final[Icon] = ...
MIRROR_16: Final[Icon] = ...
ELLIPSIS_16: Final[Icon] = ...
DASH_24: Final[Icon] = ...
AGENT_24: Final[Icon] = ...
COPILOT_WARNING_16: Final[Icon] = ...
FEED_MERGED_16: Final[Icon] = ...
SORT_ASC_16: Final[Icon] = ...
BOOKMARK_24: Final[Icon] = ...
CLOCK_24: Final[Icon] = ...
APPS_24: Final[Icon] = ...
ARROW_UP_24: Final[Icon] = ...
HEART_FILL_24: Final[Icon] = ...
FEED_DISCUSSION_16: Final[Icon] = ...
TAB_EXTERNAL_16: Final[Icon] = ...
LOGO_GIST_24: Final[Icon] = ...
BOOKMARK_SLASH_FILL_24: Final[Icon] = ...
PASSKEY_FILL_16: Final[Icon] = ...
ISSUE_OPENED_16: Final[Icon] = ...
SLIDERS_16: Final[Icon] = ...
TRACKED_BY_CLOSED_NOT_PLANNED_16: Final[Icon] = ...
ARROW_UP_16: Final[Icon] = ...
SPARKLES_FILL_16: Final[Icon] = ...
ISSUE_DRAFT_24: Final[Icon] = ...
BOOLEAN_ON_24: Final[Icon] = ...
PLAY_16: Final[Icon] = ...
FILE_REMOVED_24: Final[Icon] = ...
PASTE_24: Final[Icon] = ...
ZOOM_OUT_24: Final[Icon] = ...
TAB_24: Final[Icon] = ...
HISTORY_16: Final[Icon] = ...
DICE_16: Final[Icon] = ...
FEED_PULL_REQUEST_DRAFT_16: Final[Icon] = ...
HASH_16: Final[Icon] = ...
SQUARE_CIRCLE_24: Final[Icon] = ...
ALERT_24: Final[Icon] = ...
GEAR_16: Final[Icon] = ...
FILE_DIFF_24: Final[Icon] = ...
FILE_DIRECTORY_SYMLINK_24: Final[Icon] = ...
NOTE_24: Final[Icon] = ...
