// This file was generated. DO NOT EDIT.
use crate::{Icon, icons};

pub(super) fn find_part_1(slug: &str) -> Option<Icon> {
    match slug {
        "unverified-24" => Some(icons::UNVERIFIED_24),
        "id-badge-24" => Some(icons::ID_BADGE_24),
        "checkbox-fill-16" => Some(icons::CHECKBOX_FILL_16),
        "project-24" => Some(icons::PROJECT_24),
        "feed-person-16" => Some(icons::FEED_PERSON_16),
        "unmute-16" => Some(icons::UNMUTE_16),
        "file-directory-24" => Some(icons::FILE_DIRECTORY_24),
        "smiley-neutral-24" => Some(icons::SMILEY_NEUTRAL_24),
        "read-16" => Some(icons::READ_16),
        "arrow-up-left-24" => Some(icons::ARROW_UP_LEFT_24),
        "shield-lock-16" => Some(icons::SHIELD_LOCK_16),
        "heart-16" => Some(icons::HEART_16),
        "ai-model-24" => Some(icons::AI_MODEL_24),
        "circle-slash-24" => Some(icons::CIRCLE_SLASH_24),
        "squirrel-24" => Some(icons::SQUIRREL_24),
        "search-16" => Some(icons::SEARCH_16),
        "heart-fill-16" => Some(icons::HEART_FILL_16),
        "boolean-off-24" => Some(icons::BOOLEAN_OFF_24),
        "bug-16" => Some(icons::BUG_16),
        "code-16" => Some(icons::CODE_16),
        "discussion-closed-16" => Some(icons::DISCUSSION_CLOSED_16),
        "compose-24" => Some(icons::COMPOSE_24),
        "shield-16" => Some(icons::SHIELD_16),
        "duplicate-24" => Some(icons::DUPLICATE_24),
        "tag-24" => Some(icons::TAG_24),
        "arrow-down-left-24" => Some(icons::ARROW_DOWN_LEFT_24),
        "mcp-16" => Some(icons::MCP_16),
        "arrow-both-24" => Some(icons::ARROW_BOTH_24),
        "beaker-24" => Some(icons::BEAKER_24),
        "home-fill-24" => Some(icons::HOME_FILL_24),
        "paperclip-24" => Some(icons::PAPERCLIP_24),
        "accessibility-inset-16" => Some(icons::ACCESSIBILITY_INSET_16),
        "tracked-by-closed-completed-24" => Some(icons::TRACKED_BY_CLOSED_COMPLETED_24),
        "plus-16" => Some(icons::PLUS_16),
        "paintbrush-16" => Some(icons::PAINTBRUSH_16),
        "file-directory-symlink-16" => Some(icons::FILE_DIRECTORY_SYMLINK_16),
        "video-24" => Some(icons::VIDEO_24),
        "sponsor-tiers-16" => Some(icons::SPONSOR_TIERS_16),
        "north-star-24" => Some(icons::NORTH_STAR_24),
        "boolean-off-16" => Some(icons::BOOLEAN_OFF_16),
        "file-moved-24" => Some(icons::FILE_MOVED_24),
        "move-to-start-16" => Some(icons::MOVE_TO_START_16),
        "info-24" => Some(icons::INFO_24),
        "chevron-down-12" => Some(icons::CHEVRON_DOWN_12),
        "code-of-conduct-16" => Some(icons::CODE_OF_CONDUCT_16),
        "fold-16" => Some(icons::FOLD_16),
        "rows-24" => Some(icons::ROWS_24),
        "project-symlink-24" => Some(icons::PROJECT_SYMLINK_24),
        "repo-delete-24" => Some(icons::REPO_DELETE_24),
        "arrow-switch-24" => Some(icons::ARROW_SWITCH_24),
        "file-moved-16" => Some(icons::FILE_MOVED_16),
        "list-unordered-24" => Some(icons::LIST_UNORDERED_24),
        "codescan-16" => Some(icons::CODESCAN_16),
        "zoom-out-16" => Some(icons::ZOOM_OUT_16),
        "markdown-24" => Some(icons::MARKDOWN_24),
        "minimize-24" => Some(icons::MINIMIZE_24),
        "file-directory-16" => Some(icons::FILE_DIRECTORY_16),
        "shield-lock-24" => Some(icons::SHIELD_LOCK_24),
        "horizontal-rule-24" => Some(icons::HORIZONTAL_RULE_24),
        "square-circle-16" => Some(icons::SQUARE_CIRCLE_16),
        "feed-repo-16" => Some(icons::FEED_REPO_16),
        "feed-public-16" => Some(icons::FEED_PUBLIC_16),
        "package-16" => Some(icons::PACKAGE_16),
        "pivot-column-16" => Some(icons::PIVOT_COLUMN_16),
        "repo-deleted-16" => Some(icons::REPO_DELETED_16),
        "megaphone-24" => Some(icons::MEGAPHONE_24),
        "diff-removed-16" => Some(icons::DIFF_REMOVED_16),
        "git-branch-check-24" => Some(icons::GIT_BRANCH_CHECK_24),
        "smiley-frown-16" => Some(icons::SMILEY_FROWN_16),
        "columns-24" => Some(icons::COLUMNS_24),
        "issue-tracked-by-16" => Some(icons::ISSUE_TRACKED_BY_16),
        "apps-16" => Some(icons::APPS_16),
        "workflow-24" => Some(icons::WORKFLOW_24),
        "bell-16" => Some(icons::BELL_16),
        "feed-rocket-16" => Some(icons::FEED_ROCKET_16),
        "unread-24" => Some(icons::UNREAD_24),
        "comment-ai-24" => Some(icons::COMMENT_AI_24),
        "diff-modified-16" => Some(icons::DIFF_MODIFIED_16),
        "trophy-16" => Some(icons::TROPHY_16),
        "copilot-48" => Some(icons::COPILOT_48),
        "heading-16" => Some(icons::HEADING_16),
        "check-circle-24" => Some(icons::CHECK_CIRCLE_24),
        "feed-tag-16" => Some(icons::FEED_TAG_16),
        "file-directory-fill-24" => Some(icons::FILE_DIRECTORY_FILL_24),
        "server-16" => Some(icons::SERVER_16),
        "skip-24" => Some(icons::SKIP_24),
        "note-16" => Some(icons::NOTE_16),
        "dot-16" => Some(icons::DOT_16),
        "device-desktop-24" => Some(icons::DEVICE_DESKTOP_24),
        "chevron-right-12" => Some(icons::CHEVRON_RIGHT_12),
        "spacing-medium-16" => Some(icons::SPACING_MEDIUM_16),
        "sign-in-24" => Some(icons::SIGN_IN_24),
        "thumbsdown-24" => Some(icons::THUMBSDOWN_24),
        "alert-fill-12" => Some(icons::ALERT_FILL_12),
        "vscode-32" => Some(icons::VSCODE_32),
        "tracked-by-closed-completed-16" => Some(icons::TRACKED_BY_CLOSED_COMPLETED_16),
        "graph-bar-vertical-16" => Some(icons::GRAPH_BAR_VERTICAL_16),
        "code-square-24" => Some(icons::CODE_SQUARE_24),
        "file-badge-24" => Some(icons::FILE_BADGE_24),
        "arrow-switch-16" => Some(icons::ARROW_SWITCH_16),
        "rocket-16" => Some(icons::ROCKET_16),
        "code-24" => Some(icons::CODE_24),
        "thumbsup-24" => Some(icons::THUMBSUP_24),
        "repo-24" => Some(icons::REPO_24),
        "codescan-checkmark-16" => Some(icons::CODESCAN_CHECKMARK_16),
        "stop-16" => Some(icons::STOP_16),
        "arrow-down-right-16" => Some(icons::ARROW_DOWN_RIGHT_16),
        "hourglass-16" => Some(icons::HOURGLASS_16),
        "home-24" => Some(icons::HOME_24),
        "meter-16" => Some(icons::METER_16),
        "image-16" => Some(icons::IMAGE_16),
        "arrow-right-16" => Some(icons::ARROW_RIGHT_16),
        "gift-16" => Some(icons::GIFT_16),
        "exclamation-24" => Some(icons::EXCLAMATION_24),
        "upload-24" => Some(icons::UPLOAD_24),
        "git-pull-request-16" => Some(icons::GIT_PULL_REQUEST_16),
        "spacing-large-16" => Some(icons::SPACING_LARGE_16),
        "triangle-right-16" => Some(icons::TRIANGLE_RIGHT_16),
        "person-add-24" => Some(icons::PERSON_ADD_24),
        "single-select-16" => Some(icons::SINGLE_SELECT_16),
        "sparkle-24" => Some(icons::SPARKLE_24),
        "image-24" => Some(icons::IMAGE_24),
        "cpu-16" => Some(icons::CPU_16),
        "dot-24" => Some(icons::DOT_24),
        "logo-github-16" => Some(icons::LOGO_GITHUB_16),
        "smiley-grin-24" => Some(icons::SMILEY_GRIN_24),
        "spacing-small-16" => Some(icons::SPACING_SMALL_16),
        "mail-16" => Some(icons::MAIL_16),
        "smiley-16" => Some(icons::SMILEY_16),
        "kebab-horizontal-24" => Some(icons::KEBAB_HORIZONTAL_24),
        "chevron-up-12" => Some(icons::CHEVRON_UP_12),
        "pin-slash-24" => Some(icons::PIN_SLASH_24),
        "globe-24" => Some(icons::GLOBE_24),
        "reply-24" => Some(icons::REPLY_24),
        "briefcase-16" => Some(icons::BRIEFCASE_16),
        "file-16" => Some(icons::FILE_16),
        "code-review-16" => Some(icons::CODE_REVIEW_16),
        "number-24" => Some(icons::NUMBER_24),
        "square-24" => Some(icons::SQUARE_24),
        "multi-select-24" => Some(icons::MULTI_SELECT_24),
        "discussion-closed-24" => Some(icons::DISCUSSION_CLOSED_24),
        "sidebar-collapse-24" => Some(icons::SIDEBAR_COLLAPSE_24),
        "browser-16" => Some(icons::BROWSER_16),
        "git-pull-request-closed-24" => Some(icons::GIT_PULL_REQUEST_CLOSED_24),
        "law-16" => Some(icons::LAW_16),
        "dot-fill-24" => Some(icons::DOT_FILL_24),
        "number-16" => Some(icons::NUMBER_16),
        "verified-24" => Some(icons::VERIFIED_24),
        "mark-github-24" => Some(icons::MARK_GITHUB_24),
        "chevron-down-24" => Some(icons::CHEVRON_DOWN_24),
        "bookmark-slash-16" => Some(icons::BOOKMARK_SLASH_16),
        "chevron-up-16" => Some(icons::CHEVRON_UP_16),
        "file-code-24" => Some(icons::FILE_CODE_24),
        "key-24" => Some(icons::KEY_24),
        "flowchart-24" => Some(icons::FLOWCHART_24),
        "pin-slash-16" => Some(icons::PIN_SLASH_16),
        "device-camera-video-24" => Some(icons::DEVICE_CAMERA_VIDEO_24),
        "redo-16" => Some(icons::REDO_16),
        "issue-tracks-16" => Some(icons::ISSUE_TRACKS_16),
        "diff-removed-24" => Some(icons::DIFF_REMOVED_24),
        "inbox-fill-16" => Some(icons::INBOX_FILL_16),
        "screen-normal-24" => Some(icons::SCREEN_NORMAL_24),
        "ellipsis-24" => Some(icons::ELLIPSIS_24),
        "x-12" => Some(icons::X_12),
        "person-add-16" => Some(icons::PERSON_ADD_16),
        "share-16" => Some(icons::SHARE_16),
        "file-media-24" => Some(icons::FILE_MEDIA_24),
        "arrow-down-24" => Some(icons::ARROW_DOWN_24),
        "spacing-small-24" => Some(icons::SPACING_SMALL_24),
        "desktop-download-24" => Some(icons::DESKTOP_DOWNLOAD_24),
        "bell-fill-16" => Some(icons::BELL_FILL_16),
        "file-added-16" => Some(icons::FILE_ADDED_16),
        "file-added-24" => Some(icons::FILE_ADDED_24),
        "credit-card-16" => Some(icons::CREDIT_CARD_16),
        "checkbox-24" => Some(icons::CHECKBOX_24),
        "rss-24" => Some(icons::RSS_24),
        "grabber-24" => Some(icons::GRABBER_24),
        "unfold-16" => Some(icons::UNFOLD_16),
        "triangle-left-16" => Some(icons::TRIANGLE_LEFT_16),
        "git-compare-16" => Some(icons::GIT_COMPARE_16),
        "bookmark-fill-24" => Some(icons::BOOKMARK_FILL_24),
        "archive-16" => Some(icons::ARCHIVE_16),
        "comment-24" => Some(icons::COMMENT_24),
        "filter-remove-24" => Some(icons::FILTER_REMOVE_24),
        "sun-24" => Some(icons::SUN_24),
        "stack-16" => Some(icons::STACK_16),
        "broadcast-24" => Some(icons::BROADCAST_24),
        "git-compare-24" => Some(icons::GIT_COMPARE_24),
        "ruby-16" => Some(icons::RUBY_16),
        "issue-reopened-16" => Some(icons::ISSUE_REOPENED_16),
        "feed-heart-16" => Some(icons::FEED_HEART_16),
        "star-16" => Some(icons::STAR_16),
        "versions-24" => Some(icons::VERSIONS_24),
        "codescan-checkmark-24" => Some(icons::CODESCAN_CHECKMARK_24),
        "bell-slash-24" => Some(icons::BELL_SLASH_24),
        "container-24" => Some(icons::CONTAINER_24),
        "check-16" => Some(icons::CHECK_16),
        "issue-closed-16" => Some(icons::ISSUE_CLOSED_16),
        "zap-16" => Some(icons::ZAP_16),
        "screen-full-16" => Some(icons::SCREEN_FULL_16),
        _ => None,
    }
}
