// This file was generated. DO NOT EDIT.
use crate::{Icon, icons};

pub(super) fn find_part_2(slug: &str) -> Option<Icon> {
    match slug {
        "wrap-24" => Some(icons::WRAP_24),
        "sign-out-16" => Some(icons::SIGN_OUT_16),
        "diff-renamed-24" => Some(icons::DIFF_RENAMED_24),
        "list-ordered-16" => Some(icons::LIST_ORDERED_16),
        "report-16" => Some(icons::REPORT_16),
        "trash-24" => Some(icons::TRASH_24),
        "smiley-grin-16" => Some(icons::SMILEY_GRIN_16),
        "strikethrough-16" => Some(icons::STRIKETHROUGH_16),
        "discussion-duplicate-16" => Some(icons::DISCUSSION_DUPLICATE_16),
        "file-symlink-file-16" => Some(icons::FILE_SYMLINK_FILE_16),
        "unfold-24" => Some(icons::UNFOLD_24),
        "package-dependents-24" => Some(icons::PACKAGE_DEPENDENTS_24),
        "triangle-down-24" => Some(icons::TRIANGLE_DOWN_24),
        "shield-slash-24" => Some(icons::SHIELD_SLASH_24),
        "boolean-on-16" => Some(icons::BOOLEAN_ON_16),
        "iterations-16" => Some(icons::ITERATIONS_16),
        "duplicate-16" => Some(icons::DUPLICATE_16),
        "device-camera-16" => Some(icons::DEVICE_CAMERA_16),
        "credit-card-24" => Some(icons::CREDIT_CARD_24),
        "plus-circle-24" => Some(icons::PLUS_CIRCLE_24),
        "git-commit-16" => Some(icons::GIT_COMMIT_16),
        "shield-x-24" => Some(icons::SHIELD_X_24),
        "single-select-24" => Some(icons::SINGLE_SELECT_24),
        "zap-24" => Some(icons::ZAP_24),
        "pause-24" => Some(icons::PAUSE_24),
        "share-android-24" => Some(icons::SHARE_ANDROID_24),
        "repo-pull-24" => Some(icons::REPO_PULL_24),
        "light-bulb-24" => Some(icons::LIGHT_BULB_24),
        "briefcase-24" => Some(icons::BRIEFCASE_24),
        "file-directory-open-fill-24" => Some(icons::FILE_DIRECTORY_OPEN_FILL_24),
        "telescope-16" => Some(icons::TELESCOPE_16),
        "cloud-offline-16" => Some(icons::CLOUD_OFFLINE_16),
        "focus-center-24" => Some(icons::FOCUS_CENTER_24),
        "sidebar-expand-16" => Some(icons::SIDEBAR_EXPAND_16),
        "markdown-16" => Some(icons::MARKDOWN_16),
        "code-square-16" => Some(icons::CODE_SQUARE_16),
        "logo-github-24" => Some(icons::LOGO_GITHUB_24),
        "diff-24" => Some(icons::DIFF_24),
        "mail-24" => Some(icons::MAIL_24),
        "chevron-right-16" => Some(icons::CHEVRON_RIGHT_16),
        "sun-16" => Some(icons::SUN_16),
        "cloud-16" => Some(icons::CLOUD_16),
        "move-to-start-24" => Some(icons::MOVE_TO_START_24),
        "issue-tracked-by-24" => Some(icons::ISSUE_TRACKED_BY_24),
        "feed-forked-16" => Some(icons::FEED_FORKED_16),
        "eye-closed-24" => Some(icons::EYE_CLOSED_24),
        "hash-24" => Some(icons::HASH_24),
        "comment-16" => Some(icons::COMMENT_16),
        "smiley-24" => Some(icons::SMILEY_24),
        "goal-24" => Some(icons::GOAL_24),
        "issue-reopened-24" => Some(icons::ISSUE_REOPENED_24),
        "repo-push-16" => Some(icons::REPO_PUSH_16),
        "play-24" => Some(icons::PLAY_24),
        "download-24" => Some(icons::DOWNLOAD_24),
        "iterations-24" => Some(icons::ITERATIONS_24),
        "three-bars-16" => Some(icons::THREE_BARS_16),
        "issue-draft-16" => Some(icons::ISSUE_DRAFT_16),
        "spacing-medium-24" => Some(icons::SPACING_MEDIUM_24),
        "tracked-by-closed-not-planned-24" => Some(icons::TRACKED_BY_CLOSED_NOT_PLANNED_24),
        "sidebar-collapse-16" => Some(icons::SIDEBAR_COLLAPSE_16),
        "no-entry-fill-12" => Some(icons::NO_ENTRY_FILL_12),
        "sliders-24" => Some(icons::SLIDERS_24),
        "issue-closed-24" => Some(icons::ISSUE_CLOSED_24),
        "person-fill-24" => Some(icons::PERSON_FILL_24),
        "graph-16" => Some(icons::GRAPH_16),
        "repo-template-16" => Some(icons::REPO_TEMPLATE_16),
        "zoom-in-16" => Some(icons::ZOOM_IN_16),
        "bell-slash-16" => Some(icons::BELL_SLASH_16),
        "unlink-16" => Some(icons::UNLINK_16),
        "cloud-offline-24" => Some(icons::CLOUD_OFFLINE_24),
        "arrow-down-left-16" => Some(icons::ARROW_DOWN_LEFT_16),
        "star-24" => Some(icons::STAR_24),
        "tasklist-16" => Some(icons::TASKLIST_16),
        "codespaces-16" => Some(icons::CODESPACES_16),
        "tab-external-24" => Some(icons::TAB_EXTERNAL_24),
        "report-24" => Some(icons::REPORT_24),
        "feed-issue-open-16" => Some(icons::FEED_ISSUE_OPEN_16),
        "blocked-16" => Some(icons::BLOCKED_16),
        "package-dependencies-16" => Some(icons::PACKAGE_DEPENDENCIES_16),
        "arrow-right-24" => Some(icons::ARROW_RIGHT_24),
        "plus-circle-16" => Some(icons::PLUS_CIRCLE_16),
        "file-directory-fill-16" => Some(icons::FILE_DIRECTORY_FILL_16),
        "smiley-frustrated-16" => Some(icons::SMILEY_FRUSTRATED_16),
        "server-24" => Some(icons::SERVER_24),
        "cloud-24" => Some(icons::CLOUD_24),
        "tag-16" => Some(icons::TAG_16),
        "thumbsup-16" => Some(icons::THUMBSUP_16),
        "multi-select-16" => Some(icons::MULTI_SELECT_16),
        "telescope-fill-16" => Some(icons::TELESCOPE_FILL_16),
        "sign-out-24" => Some(icons::SIGN_OUT_24),
        "telescope-24" => Some(icons::TELESCOPE_24),
        "pencil-ai-24" => Some(icons::PENCIL_AI_24),
        "package-dependents-16" => Some(icons::PACKAGE_DEPENDENTS_16),
        "node-24" => Some(icons::NODE_24),
        "typography-16" => Some(icons::TYPOGRAPHY_16),
        "square-fill-16" => Some(icons::SQUARE_FILL_16),
        "copilot-16" => Some(icons::COPILOT_16),
        "graph-bar-vertical-24" => Some(icons::GRAPH_BAR_VERTICAL_24),
        "repo-forked-16" => Some(icons::REPO_FORKED_16),
        "move-to-top-24" => Some(icons::MOVE_TO_TOP_24),
        "diff-ignored-16" => Some(icons::DIFF_IGNORED_16),
        "diff-ignored-24" => Some(icons::DIFF_IGNORED_24),
        "x-16" => Some(icons::X_16),
        "id-badge-16" => Some(icons::ID_BADGE_16),
        "plug-16" => Some(icons::PLUG_16),
        "x-circle-fill-12" => Some(icons::X_CIRCLE_FILL_12),
        "versions-16" => Some(icons::VERSIONS_16),
        "triangle-left-24" => Some(icons::TRIANGLE_LEFT_24),
        "screen-full-24" => Some(icons::SCREEN_FULL_24),
        "comment-discussion-24" => Some(icons::COMMENT_DISCUSSION_24),
        "checklist-24" => Some(icons::CHECKLIST_24),
        "skip-16" => Some(icons::SKIP_16),
        "diamond-24" => Some(icons::DIAMOND_24),
        "checkbox-fill-24" => Some(icons::CHECKBOX_FILL_24),
        "filter-16" => Some(icons::FILTER_16),
        "project-16" => Some(icons::PROJECT_16),
        "bookmark-filled-16" => Some(icons::BOOKMARK_FILLED_16),
        "fold-up-24" => Some(icons::FOLD_UP_24),
        "no-entry-16" => Some(icons::NO_ENTRY_16),
        "repo-template-24" => Some(icons::REPO_TEMPLATE_24),
        "history-24" => Some(icons::HISTORY_24),
        "accessibility-24" => Some(icons::ACCESSIBILITY_24),
        "arrow-up-right-16" => Some(icons::ARROW_UP_RIGHT_16),
        "calendar-16" => Some(icons::CALENDAR_16),
        "focus-center-16" => Some(icons::FOCUS_CENTER_16),
        "check-circle-fill-16" => Some(icons::CHECK_CIRCLE_FILL_16),
        "lock-24" => Some(icons::LOCK_24),
        "hubot-16" => Some(icons::HUBOT_16),
        "video-16" => Some(icons::VIDEO_16),
        "strikethrough-24" => Some(icons::STRIKETHROUGH_24),
        "feed-pull-request-open-16" => Some(icons::FEED_PULL_REQUEST_OPEN_16),
        "three-bars-24" => Some(icons::THREE_BARS_24),
        "space-16" => Some(icons::SPACE_16),
        "chevron-down-16" => Some(icons::CHEVRON_DOWN_16),
        "database-24" => Some(icons::DATABASE_24),
        "arrow-up-right-24" => Some(icons::ARROW_UP_RIGHT_24),
        "key-asterisk-24" => Some(icons::KEY_ASTERISK_24),
        "git-pull-request-closed-16" => Some(icons::GIT_PULL_REQUEST_CLOSED_16),
        "graph-24" => Some(icons::GRAPH_24),
        "code-of-conduct-24" => Some(icons::CODE_OF_CONDUCT_24),
        "cpu-24" => Some(icons::CPU_24),
        "bold-24" => Some(icons::BOLD_24),
        "project-roadmap-16" => Some(icons::PROJECT_ROADMAP_16),
        "sparkle-fill-16" => Some(icons::SPARKLE_FILL_16),
        "pencil-16" => Some(icons::PENCIL_16),
        "pin-24" => Some(icons::PIN_24),
        "eye-closed-16" => Some(icons::EYE_CLOSED_16),
        "check-circle-16" => Some(icons::CHECK_CIRCLE_16),
        "link-external-24" => Some(icons::LINK_EXTERNAL_24),
        "typography-24" => Some(icons::TYPOGRAPHY_24),
        "wrap-16" => Some(icons::WRAP_16),
        "hourglass-24" => Some(icons::HOURGLASS_24),
        "device-camera-video-16" => Some(icons::DEVICE_CAMERA_VIDEO_16),
        "git-merge-queue-16" => Some(icons::GIT_MERGE_QUEUE_16),
        "trash-16" => Some(icons::TRASH_16),
        "diff-16" => Some(icons::DIFF_16),
        "dependabot-16" => Some(icons::DEPENDABOT_16),
        "codespaces-24" => Some(icons::CODESPACES_24),
        "browser-24" => Some(icons::BROWSER_24),
        "pin-16" => Some(icons::PIN_16),
        "square-16" => Some(icons::SQUARE_16),
        "discussion-outdated-24" => Some(icons::DISCUSSION_OUTDATED_24),
        "shield-24" => Some(icons::SHIELD_24),
        "unmute-24" => Some(icons::UNMUTE_24),
        "stop-24" => Some(icons::STOP_24),
        "smiley-frustrated-24" => Some(icons::SMILEY_FRUSTRATED_24),
        "unread-16" => Some(icons::UNREAD_16),
        "git-pull-request-draft-16" => Some(icons::GIT_PULL_REQUEST_DRAFT_16),
        "paintbrush-24" => Some(icons::PAINTBRUSH_24),
        "git-branch-24" => Some(icons::GIT_BRANCH_24),
        "comment-ai-16" => Some(icons::COMMENT_AI_16),
        "inbox-24" => Some(icons::INBOX_24),
        "graph-bar-horizontal-16" => Some(icons::GRAPH_BAR_HORIZONTAL_16),
        "file-submodule-24" => Some(icons::FILE_SUBMODULE_24),
        "database-16" => Some(icons::DATABASE_16),
        "code-review-24" => Some(icons::CODE_REVIEW_24),
        "shield-x-16" => Some(icons::SHIELD_X_16),
        "feed-issue-reopen-16" => Some(icons::FEED_ISSUE_REOPEN_16),
        "crosshairs-16" => Some(icons::CROSSHAIRS_16),
        "copilot-error-16" => Some(icons::COPILOT_ERROR_16),
        "italic-24" => Some(icons::ITALIC_24),
        "link-16" => Some(icons::LINK_16),
        "spacing-large-24" => Some(icons::SPACING_LARGE_24),
        "kebab-horizontal-16" => Some(icons::KEBAB_HORIZONTAL_16),
        "bookmark-slash-24" => Some(icons::BOOKMARK_SLASH_24),
        "telescope-fill-24" => Some(icons::TELESCOPE_FILL_24),
        "cross-reference-16" => Some(icons::CROSS_REFERENCE_16),
        "link-external-16" => Some(icons::LINK_EXTERNAL_16),
        "horizontal-rule-16" => Some(icons::HORIZONTAL_RULE_16),
        "repo-push-24" => Some(icons::REPO_PUSH_24),
        "eye-24" => Some(icons::EYE_24),
        "accessibility-16" => Some(icons::ACCESSIBILITY_16),
        "columns-16" => Some(icons::COLUMNS_16),
        "globe-16" => Some(icons::GLOBE_16),
        "heart-24" => Some(icons::HEART_24),
        "alert-fill-16" => Some(icons::ALERT_FILL_16),
        "triangle-up-16" => Some(icons::TRIANGLE_UP_16),
        "repo-locked-24" => Some(icons::REPO_LOCKED_24),
        "move-to-end-24" => Some(icons::MOVE_TO_END_24),
        "repo-locked-16" => Some(icons::REPO_LOCKED_16),
        _ => None,
    }
}
