// This file was generated. DO NOT EDIT.
use crate::{Icon, icons};

pub(super) fn find_part_0(slug: &str) -> Option<Icon> {
    match slug {
        "file-zip-16" => Some(icons::FILE_ZIP_16),
        "person-16" => Some(icons::PERSON_16),
        "agent-16" => Some(icons::AGENT_16),
        "repo-forked-24" => Some(icons::REPO_FORKED_24),
        "fiscal-host-24" => Some(icons::FISCAL_HOST_24),
        "tools-16" => Some(icons::TOOLS_16),
        "git-pull-request-24" => Some(icons::GIT_PULL_REQUEST_24),
        "bookmark-16" => Some(icons::BOOKMARK_16),
        "thumbsdown-16" => Some(icons::THUMBSDOWN_16),
        "copilot-24" => Some(icons::COPILOT_24),
        "plus-24" => Some(icons::PLUS_24),
        "unlock-16" => Some(icons::UNLOCK_16),
        "file-symlink-file-24" => Some(icons::FILE_SYMLINK_FILE_24),
        "tools-24" => Some(icons::TOOLS_24),
        "loop-24" => Some(icons::LOOP_24),
        "cache-24" => Some(icons::CACHE_24),
        "codescan-24" => Some(icons::CODESCAN_24),
        "infinity-16" => Some(icons::INFINITY_16),
        "feed-issue-draft-16" => Some(icons::FEED_ISSUE_DRAFT_16),
        "triangle-right-24" => Some(icons::TRIANGLE_RIGHT_24),
        "undo-24" => Some(icons::UNDO_24),
        "download-16" => Some(icons::DOWNLOAD_16),
        "key-asterisk-16" => Some(icons::KEY_ASTERISK_16),
        "table-16" => Some(icons::TABLE_16),
        "feed-trophy-16" => Some(icons::FEED_TROPHY_16),
        "fold-24" => Some(icons::FOLD_24),
        "moon-24" => Some(icons::MOON_24),
        "law-24" => Some(icons::LAW_24),
        "file-media-16" => Some(icons::FILE_MEDIA_16),
        "maximize-16" => Some(icons::MAXIMIZE_16),
        "command-palette-24" => Some(icons::COMMAND_PALETTE_24),
        "milestone-24" => Some(icons::MILESTONE_24),
        "sparkle-16" => Some(icons::SPARKLE_16),
        "x-circle-24" => Some(icons::X_CIRCLE_24),
        "smiley-neutral-16" => Some(icons::SMILEY_NEUTRAL_16),
        "unlock-24" => Some(icons::UNLOCK_24),
        "meter-24" => Some(icons::METER_24),
        "home-16" => Some(icons::HOME_16),
        "filter-remove-16" => Some(icons::FILTER_REMOVE_16),
        "upload-16" => Some(icons::UPLOAD_16),
        "move-to-top-16" => Some(icons::MOVE_TO_TOP_16),
        "stopwatch-24" => Some(icons::STOPWATCH_24),
        "diff-modified-24" => Some(icons::DIFF_MODIFIED_24),
        "dash-16" => Some(icons::DASH_16),
        "file-badge-16" => Some(icons::FILE_BADGE_16),
        "plug-24" => Some(icons::PLUG_24),
        "project-template-16" => Some(icons::PROJECT_TEMPLATE_16),
        "unverified-16" => Some(icons::UNVERIFIED_16),
        "package-dependencies-24" => Some(icons::PACKAGE_DEPENDENCIES_24),
        "circle-slash-16" => Some(icons::CIRCLE_SLASH_16),
        "device-mobile-16" => Some(icons::DEVICE_MOBILE_16),
        "loop-16" => Some(icons::LOOP_16),
        "beaker-16" => Some(icons::BEAKER_16),
        "star-fill-16" => Some(icons::STAR_FILL_16),
        "person-24" => Some(icons::PERSON_24),
        "check-24" => Some(icons::CHECK_24),
        "redo-24" => Some(icons::REDO_24),
        "project-template-24" => Some(icons::PROJECT_TEMPLATE_24),
        "organization-24" => Some(icons::ORGANIZATION_24),
        "broadcast-16" => Some(icons::BROADCAST_16),
        "move-to-bottom-16" => Some(icons::MOVE_TO_BOTTOM_16),
        "trophy-24" => Some(icons::TROPHY_24),
        "milestone-16" => Some(icons::MILESTONE_16),
        "info-16" => Some(icons::INFO_16),
        "compose-16" => Some(icons::COMPOSE_16),
        "sync-24" => Some(icons::SYNC_24),
        "devices-16" => Some(icons::DEVICES_16),
        "mcp-24" => Some(icons::MCP_24),
        "squirrel-16" => Some(icons::SQUIRREL_16),
        "italic-16" => Some(icons::ITALIC_16),
        "sync-16" => Some(icons::SYNC_16),
        "device-mobile-24" => Some(icons::DEVICE_MOBILE_24),
        "arrow-up-left-16" => Some(icons::ARROW_UP_LEFT_16),
        "repo-clone-16" => Some(icons::REPO_CLONE_16),
        "read-24" => Some(icons::READ_24),
        "checkbox-16" => Some(icons::CHECKBOX_16),
        "copy-24" => Some(icons::COPY_24),
        "arrow-left-24" => Some(icons::ARROW_LEFT_24),
        "sidebar-expand-24" => Some(icons::SIDEBAR_EXPAND_24),
        "chevron-left-16" => Some(icons::CHEVRON_LEFT_16),
        "move-to-end-16" => Some(icons::MOVE_TO_END_16),
        "mortar-board-24" => Some(icons::MORTAR_BOARD_24),
        "feed-pull-request-closed-16" => Some(icons::FEED_PULL_REQUEST_CLOSED_16),
        "grabber-16" => Some(icons::GRABBER_16),
        "paperclip-16" => Some(icons::PAPERCLIP_16),
        "git-merge-16" => Some(icons::GIT_MERGE_16),
        "diff-added-24" => Some(icons::DIFF_ADDED_24),
        "north-star-16" => Some(icons::NORTH_STAR_16),
        "calendar-24" => Some(icons::CALENDAR_24),
        "tab-16" => Some(icons::TAB_16),
        "mark-github-16" => Some(icons::MARK_GITHUB_16),
        "screen-normal-16" => Some(icons::SCREEN_NORMAL_16),
        "bold-16" => Some(icons::BOLD_16),
        "file-24" => Some(icons::FILE_24),
        "pencil-24" => Some(icons::PENCIL_24),
        "container-16" => Some(icons::CONTAINER_16),
        "link-24" => Some(icons::LINK_24),
        "terminal-24" => Some(icons::TERMINAL_24),
        "split-view-24" => Some(icons::SPLIT_VIEW_24),
        "bookmark-slash-fill-16" => Some(icons::BOOKMARK_SLASH_FILL_16),
        "book-16" => Some(icons::BOOK_16),
        "bell-fill-24" => Some(icons::BELL_FILL_24),
        "pulse-24" => Some(icons::PULSE_24),
        "repo-pull-16" => Some(icons::REPO_PULL_16),
        "fold-down-24" => Some(icons::FOLD_DOWN_24),
        "chevron-right-24" => Some(icons::CHEVRON_RIGHT_24),
        "minimize-16" => Some(icons::MINIMIZE_16),
        "file-submodule-16" => Some(icons::FILE_SUBMODULE_16),
        "git-branch-16" => Some(icons::GIT_BRANCH_16),
        "file-binary-16" => Some(icons::FILE_BINARY_16),
        "repo-16" => Some(icons::REPO_16),
        "paper-airplane-24" => Some(icons::PAPER_AIRPLANE_24),
        "share-android-16" => Some(icons::SHARE_ANDROID_16),
        "flame-24" => Some(icons::FLAME_24),
        "home-fill-16" => Some(icons::HOME_FILL_16),
        "chevron-left-24" => Some(icons::CHEVRON_LEFT_24),
        "shield-check-24" => Some(icons::SHIELD_CHECK_24),
        "vscode-16" => Some(icons::VSCODE_16),
        "search-24" => Some(icons::SEARCH_24),
        "clock-16" => Some(icons::CLOCK_16),
        "clock-fill-24" => Some(icons::CLOCK_FILL_24),
        "arrow-left-16" => Some(icons::ARROW_LEFT_16),
        "feed-star-16" => Some(icons::FEED_STAR_16),
        "command-palette-16" => Some(icons::COMMAND_PALETTE_16),
        "arrow-both-16" => Some(icons::ARROW_BOTH_16),
        "git-merge-24" => Some(icons::GIT_MERGE_24),
        "star-fill-24" => Some(icons::STAR_FILL_24),
        "bell-24" => Some(icons::BELL_24),
        "ruby-24" => Some(icons::RUBY_24),
        "package-24" => Some(icons::PACKAGE_24),
        "skip-fill-24" => Some(icons::SKIP_FILL_24),
        "graph-bar-horizontal-24" => Some(icons::GRAPH_BAR_HORIZONTAL_24),
        "skip-fill-16" => Some(icons::SKIP_FILL_16),
        "cross-reference-24" => Some(icons::CROSS_REFERENCE_24),
        "heading-24" => Some(icons::HEADING_24),
        "unlink-24" => Some(icons::UNLINK_24),
        "rows-16" => Some(icons::ROWS_16),
        "quote-16" => Some(icons::QUOTE_16),
        "no-entry-24" => Some(icons::NO_ENTRY_24),
        "quote-24" => Some(icons::QUOTE_24),
        "ai-model-16" => Some(icons::AI_MODEL_16),
        "project-symlink-16" => Some(icons::PROJECT_SYMLINK_16),
        "move-to-bottom-24" => Some(icons::MOVE_TO_BOTTOM_24),
        "inbox-16" => Some(icons::INBOX_16),
        "smiley-frown-24" => Some(icons::SMILEY_FROWN_24),
        "file-zip-24" => Some(icons::FILE_ZIP_24),
        "accessibility-inset-24" => Some(icons::ACCESSIBILITY_INSET_24),
        "issue-opened-24" => Some(icons::ISSUE_OPENED_24),
        "stack-24" => Some(icons::STACK_24),
        "fold-down-16" => Some(icons::FOLD_DOWN_16),
        "question-24" => Some(icons::QUESTION_24),
        "chevron-up-24" => Some(icons::CHEVRON_UP_24),
        "blocked-24" => Some(icons::BLOCKED_24),
        "moon-16" => Some(icons::MOON_16),
        "zoom-in-24" => Some(icons::ZOOM_IN_24),
        "rocket-24" => Some(icons::ROCKET_24),
        "triangle-down-16" => Some(icons::TRIANGLE_DOWN_16),
        "arrow-down-16" => Some(icons::ARROW_DOWN_16),
        "checklist-16" => Some(icons::CHECKLIST_16),
        "rel-file-path-24" => Some(icons::REL_FILE_PATH_24),
        "eye-16" => Some(icons::EYE_16),
        "unwrap-24" => Some(icons::UNWRAP_24),
        "terminal-16" => Some(icons::TERMINAL_16),
        "x-circle-fill-24" => Some(icons::X_CIRCLE_FILL_24),
        "git-commit-24" => Some(icons::GIT_COMMIT_24),
        "fold-up-16" => Some(icons::FOLD_UP_16),
        "feed-plus-16" => Some(icons::FEED_PLUS_16),
        "gear-24" => Some(icons::GEAR_24),
        "vscode-48" => Some(icons::VSCODE_48),
        "tasklist-24" => Some(icons::TASKLIST_24),
        "dot-fill-16" => Some(icons::DOT_FILL_16),
        "desktop-download-16" => Some(icons::DESKTOP_DOWNLOAD_16),
        "location-24" => Some(icons::LOCATION_24),
        "inbox-fill-24" => Some(icons::INBOX_FILL_24),
        "passkey-fill-24" => Some(icons::PASSKEY_FILL_24),
        "node-16" => Some(icons::NODE_16),
        "git-branch-check-16" => Some(icons::GIT_BRANCH_CHECK_16),
        "fiscal-host-16" => Some(icons::FISCAL_HOST_16),
        "shield-check-16" => Some(icons::SHIELD_CHECK_16),
        "file-directory-open-fill-16" => Some(icons::FILE_DIRECTORY_OPEN_FILL_16),
        "mention-24" => Some(icons::MENTION_24),
        "device-desktop-16" => Some(icons::DEVICE_DESKTOP_16),
        "alert-fill-24" => Some(icons::ALERT_FILL_24),
        "pause-16" => Some(icons::PAUSE_16),
        "mute-16" => Some(icons::MUTE_16),
        "triangle-up-24" => Some(icons::TRIANGLE_UP_24),
        "project-roadmap-24" => Some(icons::PROJECT_ROADMAP_24),
        "stopwatch-16" => Some(icons::STOPWATCH_16),
        "organization-16" => Some(icons::ORGANIZATION_16),
        "arrow-down-right-24" => Some(icons::ARROW_DOWN_RIGHT_24),
        "alert-16" => Some(icons::ALERT_16),
        "workflow-16" => Some(icons::WORKFLOW_16),
        "rel-file-path-16" => Some(icons::REL_FILE_PATH_16),
        "diff-renamed-16" => Some(icons::DIFF_RENAMED_16),
        "git-merge-queue-24" => Some(icons::GIT_MERGE_QUEUE_24),
        "verified-16" => Some(icons::VERIFIED_16),
        "question-16" => Some(icons::QUESTION_16),
        "copy-16" => Some(icons::COPY_16),
        "paper-airplane-16" => Some(icons::PAPER_AIRPLANE_16),
        "shield-slash-16" => Some(icons::SHIELD_SLASH_16),
        _ => None,
    }
}
